<?php

$LANG = array(
    'organization' => 'Organizacija',
    'name' => 'Ime',
    'website' => 'Spletišče',
    'work_phone' => 'Službeni telefon',
    'address' => 'Naslov',
    'address1' => 'Ulica',
    'address2' => 'Hišna št./Stanovanje',
    'city' => 'Mesto',
    'state' => 'Regija/pokrajina',
    'postal_code' => 'Poštna št.',
    'country_id' => 'Država',
    'contacts' => 'Kontakti',
    'first_name' => 'Ime',
    'last_name' => 'Priimek',
    'phone' => 'Telefon',
    'email' => 'E-pošta',
    'additional_info' => 'Dodatni podatki',
    'payment_terms' => 'Plačilni pogoji',
    'currency_id' => 'Valuta',
    'size_id' => 'Velikost podjetja',
    'industry_id' => 'Industrija',
    'private_notes' => 'Zasebni zaznamki',
    'invoice' => 'Račun',
    'client' => 'Stranka',
    'invoice_date' => 'Datum računa',
    'due_date' => 'Rok plačila',
    'invoice_number' => 'Št. računa',
    'invoice_number_short' => 'Račun #',
    'po_number' => 'Št. naročilnice',
    'po_number_short' => 'Naročilo #',
    'frequency_id' => 'Kako pogosto',
    'discount' => 'Popust',
    'taxes' => 'Davki',
    'tax' => 'DDV',
    'item' => 'Postavka',
    'description' => 'Opis',
    'unit_cost' => 'Cena',
    'quantity' => 'Količina',
    'line_total' => 'Skupaj',
    'subtotal' => 'Neto',
    'paid_to_date' => 'Že plačano',
    'balance_due' => 'Za plačilo',
    'invoice_design_id' => 'Izgled',
    'terms' => 'Pogoji',
    'your_invoice' => 'Vaš račun',
    'remove_contact' => 'Odstrani kontakt',
    'add_contact' => 'Dodaj kontakt',
    'create_new_client' => 'Ustvari novo stranko',
    'edit_client_details' => 'Uredi podatke o stranki',
    'enable' => 'Omogoči',
    'learn_more' => 'Izvedi več',
    'manage_rates' => 'Urejaj cene',
    'note_to_client' => 'Zapisek za stranko',
    'invoice_terms' => 'Pogoji računa',
    'save_as_default_terms' => 'Shrani kot privzete pogoje',
    'download_pdf' => 'Prenesi PDF',
    'pay_now' => 'Plačaj zdaj',
    'save_invoice' => 'Shrani račun',
    'clone_invoice' => 'Kopiraj v račun',
    'archive_invoice' => 'Arhiviraj račun',
    'delete_invoice' => 'Zbriši račun',
    'email_invoice' => 'Pošlji račun na e-pošto ',
    'enter_payment' => 'Vnesi plačilo',
    'tax_rates' => 'Davčne stopnje',
    'rate' => 'Cena',
    'settings' => 'Nastavitve',
    'enable_invoice_tax' => 'Omogoči specificiranje <b>davka na računu</b>',
    'enable_line_item_tax' => 'Omogoči specificiranje <b>davka na postavki</b>',
    'dashboard' => 'Nadzorna plošča',
    'dashboard_totals_in_all_currencies_help' => 'Opomba: dodajte :link z imenom ":name", da prikažete vsote z eno samo osnovno valuto.',
    'clients' => 'Stranke',
    'invoices' => 'Računi',
    'payments' => 'Plačila',
    'credits' => 'Dobropisi',
    'history' => 'Zgodovina',
    'search' => 'Išči',
    'sign_up' => 'Prijavi se',
    'guest' => 'Gost',
    'company_details' => 'Podatki podjetja',
    'online_payments' => 'Spletna plačila',
    'notifications' => 'Obvestila',
    'import_export' => 'Uvoz | Izvoz',
    'done' => 'Končano',
    'save' => 'Shrani',
    'create' => 'Ustvari',
    'upload' => 'Naloži',
    'import' => 'Uvozi',
    'download' => 'Prenesi',
    'cancel' => 'Prekliči',
    'close' => 'Zapri',
    'provide_email' => 'Prosim vnesi pravilen elektronski naslov',
    'powered_by' => 'Poganja',
    'no_items' => 'Ni artiklov',
    'recurring_invoices' => 'Ponavljajoči računi',
    'recurring_help' => '<p>Samodejno pošlje strankam enake račune tedensko, dvakrat mesečno, mesečno, četrtletno ali letno. </p>
        <p>Uporaba: MESEC, :ČETRTLETJE ali: LETO za dinamične datume. Osnovna matematika deluje, kot tudi, na primer: MESEC-1.</p>
        <p>Primer dinamičnih spremenljivk računa:</p>
        <ul>
          <li>"Fitnes članarina za mesec :MESEC" >> "Fitnes članarina za mesec Julij"</li>
          <li>":LETO+1 letna članarina" >> "2015 Letna članarina"</li>
          <li>"Predujem za :ČETRTLETJE+1" >> "Predujem za Q2"</li>
        </ul>',
    'recurring_quotes' => 'Ponavljajoči predračuni',
    'in_total_revenue' => 'celotni prihodki',
    'billed_client' => 'zaračunana stranka',
    'billed_clients' => 'zaračunane stranke',
    'active_client' => 'aktivna stranka',
    'active_clients' => 'aktivne stranke',
    'invoices_past_due' => 'Zapadli računi',
    'upcoming_invoices' => 'Prihajajoči računi',
    'average_invoice' => 'Povprečen račun',
    'archive' => 'Arhiv',
    'delete' => 'Odstrani',
    'archive_client' => 'Arhiviraj stranko',
    'delete_client' => 'Odstrani stranko',
    'archive_payment' => 'Arhiviraj plačilo',
    'delete_payment' => 'Odstrani plačilo',
    'archive_credit' => 'Arhiviraj dobropis',
    'delete_credit' => 'Odstrani dobropis',
    'show_archived_deleted' => 'Prikaži akhivirano/odstranjeno',
    'filter' => 'Filter',
    'new_client' => 'Nova stranka',
    'new_invoice' => 'Nov račun',
    'new_payment' => 'Vnesi plačilo',
    'new_credit' => 'Vnesi dobropis',
    'contact' => 'Kontakt',
    'date_created' => 'Datum vnosa',
    'last_login' => 'Zadnja prijava',
    'balance' => 'Saldo',
    'action' => 'Ukaz',
    'status' => 'Stanje',
    'invoice_total' => 'Znesek',
    'frequency' => 'Pogostost',
    'range' => 'Razpon',
    'start_date' => 'Datum začetka',
    'end_date' => 'Datum zapadlost',
    'transaction_reference' => 'Referenca transakcije',
    'method' => 'Sredstvo',
    'payment_amount' => 'Znesek plačila',
    'payment_date' => 'Datum plačila',
    'credit_amount' => 'Znesek dobropisa',
    'credit_balance' => 'Saldo dobropisa',
    'credit_date' => 'Datum dobropisa',
    'empty_table' => 'V tabeli ni podatkov',
    'select' => 'Izberi',
    'edit_client' => 'Uredi stranko',
    'edit_invoice' => 'Uredi račun',
    'create_invoice' => 'Ustvari račun',
    'enter_credit' => 'Vnesi dobropis',
    'last_logged_in' => 'Zadnja prijava',
    'details' => 'Podrobnosti',
    'standing' => 'Stanje',
    'credit' => 'Dobropis',
    'activity' => 'Dejavnost',
    'date' => 'Datum',
    'message' => 'Sporočilo',
    'adjustment' => 'Prilagoditev',
    'are_you_sure' => 'Ali ste prepričani?',
    'payment_type_id' => 'Način plačila',
    'amount' => 'Znesek',
    'work_email' => 'E-pošta',
    'language_id' => 'Jezik',
    'timezone_id' => 'Časovni pas',
    'date_format_id' => 'Oblika datuma',
    'datetime_format_id' => 'Oblika datuma in ure',
    'users' => 'Uporabniki',
    'localization' => 'Lokalizacija',
    'remove_logo' => 'Odstrani logotip',
    'logo_help' => 'Podprto: JPEG, GIF in PNG',
    'payment_gateway' => 'Plačilni prehodi',
    'gateway_id' => 'Prehod',
    'email_notifications' => 'E-poštna obvestila',
    'email_sent' => 'Pošlji e-pošto ob <b>poslanem</b> računu',
    'email_viewed' => 'Pošlji e-pošto ob <b>ogledanem</b> računu',
    'email_paid' => 'Pošlji e-pošto ob <b>plačanem</b> računu',
    'site_updates' => 'Posodobitve strani',
    'custom_messages' => 'Obvestila po meri',
    'default_email_footer' => 'Privzeti <b>podpis e-pošte</b>',
    'select_file' => 'Prosim izberi datoteko',
    'first_row_headers' => 'Uporabi prvo vrstico za glavo',
    'column' => 'Stolpec',
    'sample' => 'Vzorec',
    'import_to' => 'Uvozi v',
    'client_will_create' => 'stranka bo ustvarjena',
    'clients_will_create' => 'stranke bodo ustvarjene',
    'email_settings' => 'Nastavitve e-pošte',
    'client_view_styling' => 'Izgled pogleda za stranke',
    'pdf_email_attachment' => 'Pripni PDF',
    'custom_css' => 'CSS po meri',
    'import_clients' => 'Uvoz strankinih podatkov',
    'csv_file' => 'CSV datoteka',
    'export_clients' => 'Izvoz strankinih podatkov',
    'created_client' => 'Stranka uspešno ustvarjena',
    'created_clients' => 'Število uspešno ustvarjenih strank: :count',
    'updated_settings' => 'Nastavitve uspešno posodobljene',
    'removed_logo' => 'Uspešno odstranjen logotip',
    'sent_message' => 'Sporočilo uspešno poslano',
    'invoice_error' => 'Prosim izberite stranko in popravite napake',
    'limit_clients' => 'To bo preseglo maksimalno število klientov: :count',
    'payment_error' => 'Pri izvedbi plačila je prišlo do napake. Prosim poizkusite ponovno.',
    'registration_required' => 'Za pošiljanje računa prek e-pošte se prijavite',
    'confirmation_required' => 'Prosim potrdite vaš elektronski naslov, :link za ponovno pošiljanje potrditvenega sporočila.',
    'updated_client' => 'Uspešno posodobljena stranka',
    'archived_client' => 'Stranka uspešno arhivirana',
    'archived_clients' => 'Število uspešno arhiviranih strank: :count clients',
    'deleted_client' => 'Stranka uspešno odstranjena',
    'deleted_clients' => 'Število uspešno odstranjenih strank: :count',
    'updated_invoice' => 'Račun uspešno posodobljen',
    'created_invoice' => 'Račun uspešno ustvarjen',
    'cloned_invoice' => 'Račun uspešno kloniran',
    'emailed_invoice' => 'Račun uspešno poslan',
    'and_created_client' => 'in ustvarjena stranka',
    'archived_invoice' => 'Račun uspešno arhiviran',
    'archived_invoices' => 'Število uspešno arhiviranih računov: :count invoices',
    'deleted_invoice' => 'Račun uspešno odstranjen',
    'deleted_invoices' => 'Število uspešno odstranjenih ponudb: :count invoices',
    'created_payment' => 'Plačilo uspešno ustvarjeno',
    'created_payments' => 'Število uspešno ustvarjenih plačil: :count',
    'archived_payment' => 'Plačilo uspešno arhivirano',
    'archived_payments' => 'Število uspešno arhiviranih plačil: :count',
    'deleted_payment' => 'Plačilo uspešno odstranjeno',
    'deleted_payments' => 'Število uspešno odstranjenih plačil: :count',
    'applied_payment' => 'Plačilo uspešno potrjeno',
    'created_credit' => 'Dobropis uspešno ustvarjen',
    'archived_credit' => 'Dobropis uspešno arhiviran',
    'archived_credits' => 'Število uspešno arhiviranih dobropisov: :count',
    'deleted_credit' => 'Dobropis uspešno odstranjen',
    'deleted_credits' => 'Število uspešno odstranjenih dobropisov: :count',
    'imported_file' => 'Uvoz datoteke uspešen',
    'updated_vendor' => 'Prodajalec uspešno posodobljen',
    'created_vendor' => 'Prodajalec uspešno ustvarjen',
    'archived_vendor' => 'Prodajalec uspešno arhiviran',
    'archived_vendors' => 'Število uspešno arhiviranih prodajalcev: :count clients',
    'deleted_vendor' => 'Prodajalec uspešno odstranjen',
    'deleted_vendors' => 'Število uspešno odstranjenih prodajalcev: :count',
    'confirmation_subject' => 'Potrditev Invoice Ninja računa',
    'confirmation_header' => 'Potrditev računa',
    'confirmation_message' => 'Prosim da za potrditev računa obiščete povezavo ',
    'invoice_subject' => 'Nov račun :number od :account',
    'invoice_message' => 'Za ogled vašega računa v znesku :amount, kliknite povezavo spodaj.',
    'payment_subject' => 'Plačilo prejeto',
    'payment_message' => 'Hvala za vaše plačilo v znesku: :amount.',
    'email_salutation' => 'Spoštovani :name;',
    'email_signature' => 'Lep pozdrav,',
    'email_from' => 'Ekipa Invoice Ninja',
    'invoice_link_message' => 'Za ogled računa kliknite na povezavo spodaj:',
    'notification_invoice_paid_subject' => 'Stranka :client je plačala račun :invoice',
    'notification_invoice_sent_subject' => 'Račun :invoice je bil poslan stranki :client',
    'notification_invoice_viewed_subject' => 'Stranka :client si je ogledala račun :invoice',
    'notification_invoice_paid' => 'Stranka :client je plačala račun :invoice v znesku :amount.',
    'notification_invoice_sent' => 'Stranki :client je bil poslan račun :invoice v znesku :amount',
    'notification_invoice_viewed' => 'Stranka :client si je ogledala Račun :invoice v znesku: :amount.',
    'reset_password' => 'Vaše geslo lahko ponastavite s pritiskom na gumb:',
    'secure_payment' => 'Varno plačilo',
    'card_number' => 'Št. kartice',
    'expiration_month' => 'Mesec poteka',
    'expiration_year' => 'Leto poteka',
    'cvv' => 'CVV',
    'logout' => 'Odjava',
    'sign_up_to_save' => 'Prijavite se, da shranite svoje delo',
    'agree_to_terms' => 'Strinjam se s :terms',
    'terms_of_service' => 'Pogoji uporabe',
    'email_taken' => 'Ta e-poštni naslov je že v uporabi',
    'working' => 'V delu',
    'success' => 'Uspešno izvedeno',
    'success_message' => 'Vaša registracija je bila uspešna! Za potrditev kliknite na povezavo v sporočilu, ki ga boste prejeli na vaš e-poštni naslov.',
    'erase_data' => 'Vač račun ni registriran. Vaši podatki bodo izbrisani.',
    'password' => 'Geslo',
    'pro_plan_product' => 'Pro paket',
    'pro_plan_success' => 'Zahvaljujemo se vam za izbiro Invoice Ninja Pro paketa!<p/>&nbsp;<br/>
<b>Naslednji Koraki</b><p/>Račun je bilo poslan na e-poštni naslov, povezan z vašim računom. Če želite odkleniti vse mega Pro funkcije, sledite navodilom na računu.<p/>
Ne morete najti računa? Potrebujete dodatno pomoč? Z veseljem bomo pomagali. Pošljite nam e-pošto na contact@invoiceninja.com',
    'unsaved_changes' => 'Imate neshranjene spremembe',
    'custom_fields' => 'Polja po meri',
    'company_fields' => 'Polja podjetja',
    'client_fields' => 'Polja stranke',
    'field_label' => 'Naslov polja',
    'field_value' => 'Vrednost polja',
    'edit' => 'Uredi',
    'set_name' => 'Nastavi ime podjetja',
    'view_as_recipient' => 'Prikaži kot prejemnik',
    'product_library' => 'Knjižnica izdelkov',
    'product' => 'Izdelek',
    'products' => 'Izdelki',
    'fill_products' => 'Samodejno vnesi izdelke',
    'fill_products_help' => 'Izbira izdelka bo samodejno <b>vnesla opis in ceno</b>',
    'update_products' => 'Samodejno posodobi izdelke',
    'update_products_help' => 'Posodobitev računa bo samodejno <b>posodobila knjižnico izdelkov</b>',
    'create_product' => 'Dodaj izdelek',
    'edit_product' => 'Uredi izdelek',
    'archive_product' => 'Arhiviraj izdelek',
    'updated_product' => 'Izdelek uspešno posodobljen',
    'created_product' => 'Izdelek uspešno ustvarjen',
    'archived_product' => 'Izdelek uspešno arhiviran',
    'pro_plan_custom_fields' => ':link za uporabo Polj po meri z prijavo v Pro Plan',
    'advanced_settings' => 'Napredne nastavitve',
    'pro_plan_advanced_settings' => ':link za uporabo naprednih nastavitev z prijavo v Pro Plan',
    'invoice_design' => 'Izgled računa',
    'specify_colors' => 'Določi darve',
    'specify_colors_label' => 'Določi barve v računu',
    'chart_builder' => 'Ustvarjalec grafikonov',
    'ninja_email_footer' => 'Ustvarjeno s/z :site | Ustvari. Pošlji. Prejmi plačilo.',
    'go_pro' => 'Prestopi na Pro plan',
    'quote' => 'Predračun',
    'quotes' => 'Predračuni',
    'quote_number' => 'Št. predračuna',
    'quote_number_short' => 'Predračun #',
    'quote_date' => 'Datum predračuna',
    'quote_total' => 'Znesek predračuna',
    'your_quote' => 'Vaš predračun',
    'total' => 'Skupaj',
    'clone' => 'Kloniraj',
    'new_quote' => 'Nov predračun',
    'create_quote' => 'Ustvari predračun',
    'edit_quote' => 'Uredi predračun',
    'archive_quote' => 'Arhiviraj predračun',
    'delete_quote' => 'Odstrani ponubdo',
    'save_quote' => 'Shrani predračun',
    'email_quote' => 'Pošlji predračun',
    'clone_quote' => 'Kopiraj v predračun',
    'convert_to_invoice' => 'Pretvori v račun',
    'view_invoice' => 'Ogled računa',
    'view_client' => 'Ogled stranke',
    'view_quote' => 'Ogled predračuna',
    'updated_quote' => 'Predračun uspešno posodobljen',
    'created_quote' => 'Predračun uspešno ustvarjen',
    'cloned_quote' => 'Predračun uspešno podvojen',
    'emailed_quote' => 'Predračun uspešno poslan',
    'archived_quote' => 'Predračun uspešno arhiviran',
    'archived_quotes' => 'Število uspešno arhiviranih predračunov:',
    'deleted_quote' => 'Predračun uspešno odstranjen',
    'deleted_quotes' => 'Število uspešno odstranjenih predračunov: :count',
    'converted_to_invoice' => 'Predračun uspešno pretvorjen v račun',
    'quote_subject' => 'Nov predračun :number od :account',
    'quote_message' => 'Za ogled predračuna v vrednosti :amount, kliknite na povezavo spodaj.',
    'quote_link_message' => 'Za ogled predračuna stranke, kliknite na povezavo spodaj:',
    'notification_quote_sent_subject' => 'Predračun :invoice je bil poslan k/na :client',
    'notification_quote_viewed_subject' => 'Predračun :invoice si :client ogledal/a',
    'notification_quote_sent' => 'Stranki :client je bil poslan predračun :invoice v znesku: :amount.',
    'notification_quote_viewed' => 'Stranka :client si je ogledala predračun :invoice v znesku: :amount.',
    'session_expired' => 'Vaša seja je potekla.',
    'invoice_fields' => 'Polja računa',
    'invoice_options' => 'Možnosti računa',
    'hide_paid_to_date' => 'Skrij datum plačila',
    'hide_paid_to_date_help' => 'Prikaži le "Plačano" polje v računu, nakar je bilo plačilo prejeto.',
    'charge_taxes' => 'Zaračunaj davke',
    'user_management' => 'Uporabniki',
    'add_user' => 'Dodaj uporabnika',
    'send_invite' => 'Pošlji povabilo',
    'sent_invite' => 'Povabilo uspešno poslano',
    'updated_user' => 'Uporabnik uspešno posodobljen',
    'invitation_message' => 'Prejeli ste vabilo od :invitor. ',
    'register_to_add_user' => 'Za dodajanje uporabnikov se prijavite.',
    'user_state' => 'Stanje',
    'edit_user' => 'Uredi uporabnika',
    'delete_user' => 'Odstrani uporabnika',
    'active' => 'Aktivno',
    'pending' => 'V teku',
    'deleted_user' => 'Uporabnik uspešno odstranjen',
    'confirm_email_invoice' => 'Ali ste prepričani da želite poslati ta račun na e-pošto?',
    'confirm_email_quote' => 'Ali ste prepričani da želite poslati predračun na e-pošto?',
    'confirm_recurring_email_invoice' => 'Ali ste prepričani da želite polati ta račun na e-pošto?',
    'confirm_recurring_email_invoice_not_sent' => 'Ali ste prepričani, da želite začeti ponavljanje?',
    'cancel_account' => 'Odstani račun',
    'cancel_account_message' => 'Opozorilo: Vaš račun bo trajno zbrisan. Razveljavitev ni mogoča.',
    'go_back' => 'Nazaj',
    'data_visualizations' => 'Vizualizacija podatkov',
    'sample_data' => 'Prikazani so vzorčni podatki',
    'hide' => 'Skrij',
    'new_version_available' => 'Nova različica :releases_link je na voljo. Trenutna različica: :user_version, Zadnja rezličica: :latest_version',
    'invoice_settings' => 'Nastavitve računa',
    'invoice_number_prefix' => 'Predpona računa',
    'invoice_number_counter' => 'Števec za račun',
    'quote_number_prefix' => 'Predpona številke predračuna',
    'quote_number_counter' => 'Števec številke predračuna',
    'share_invoice_counter' => 'Deli števec za račun',
    'invoice_issued_to' => 'Račun izdan za',
    'invalid_counter' => 'Da bi preprečili morebiten konflikt nastavite predpono računom ali predračunom',
    'mark_sent' => 'Označi kot poslano',
    'gateway_help_1' => ':link za prijavo na Authorize.net.',
    'gateway_help_2' => ':link za prijavo na Authorize.net.',
    'gateway_help_17' => ':link da pridobite PayPal API podpis.',
    'gateway_help_27' => ':link za prijavo na 2Checkout.com. Za zagotovitev da bodo plačiia izsledena nastavite :complete_link za preusmeritveni naslov (URL) pod Account > Site Management v 2Checkout portalu.',
    'gateway_help_60' => ':link da ustvariš WePay račun.',
    'more_designs' => 'Več osnutkov',
    'more_designs_title' => 'Dodatni stili',
    'more_designs_cloud_header' => 'Za več osnutkov nadgradi na Pro Plan',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Nakup',
    'bought_designs' => 'Dodaten usnutek računa uspešno dodan',
    'sent' => 'Poslano',
    'vat_number' => 'Davčna št.',
    'timesheets' => 'Časovni listi',
    'payment_title' => 'Vnesite vaše podatke za izstavitev računa in kreditne kartice',
    'payment_cvv' => '*To je 3-4 mestna številka na hrbtni strani vaše kartice',
    'payment_footer1' => '*Naslov za izstavitev računa se mora ujemati z naslovom, povezanim s kreditno kartico.',
    'payment_footer2' => '*Prosim kliknite "Plačaj zdaj" samo enkrat - Transakcija lahko traja tudi do 1 minute.',
    'id_number' => 'ID št.',
    'white_label_link' => 'White Label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'White Label licenca omogočena',
    'white_labeled' => 'White labeled',
    'restore' => 'Obnovitev',
    'restore_invoice' => 'Obnovi račun',
    'restore_quote' => 'Obnovi predračun',
    'restore_client' => 'Obnovi stranko',
    'restore_credit' => 'Obnovi dobropis',
    'restore_payment' => 'Obnovi plačilo',
    'restored_invoice' => 'Račun uspešno obnovljen',
    'restored_quote' => 'Predračun uspešno obnovljen',
    'restored_client' => 'Stranka uspešno obnovljena',
    'restored_payment' => 'Plačilo uspešno obnovljeno',
    'restored_credit' => 'Dobropis uspešno obnovljen',
    'reason_for_canceling' => 'Povejte nam razlog za vaš odhod in s tem pomagajte nam izboljšati našo spletno stran. ',
    'discount_percent' => 'Odstotek',
    'discount_amount' => 'Znesek',
    'invoice_history' => 'Zgodovina računa',
    'quote_history' => 'Zgodovina predračuna',
    'current_version' => 'Trenutna različica',
    'select_version' => 'Izberi različico',
    'view_history' => 'Ogled zgodovine',
    'edit_payment' => 'Uredi plačilo',
    'updated_payment' => 'Plačilo uspešno posodobljeno',
    'deleted' => 'Odstranjeno',
    'restore_user' => 'Obnovi uporabnika',
    'restored_user' => 'Uporabnik uspešno obnovljen',
    'show_deleted_users' => 'Prikaži odstranjene uporabnike',
    'email_templates' => 'Predloge za e-pošto',
    'invoice_email' => 'Račun',
    'payment_email' => 'Potrdilo',
    'quote_email' => 'Predračun',
    'reset_all' => 'Ponastavi vse',
    'approve' => 'Potrdi',
    'token_billing_type_id' => 'Plačilo prek avtorizacije (Token Billing)',
    'token_billing_help' => 'Shrani podrobnosti plačila z WePay, Stripe, Braintree ali GoCardless.',
    'token_billing_1' => 'Onemogočeno',
    'token_billing_2' => 'Opt-in - polje je prikazano, vendar ne izbrano',
    'token_billing_3' => 'Opt-out - polje je prikazano in izbrano',
    'token_billing_4' => 'Vedno',
    'token_billing_checkbox' => 'Shrani podrobnosti kreditne kartice',
    'view_in_gateway' => 'Pogled v :gateway',
    'use_card_on_file' => 'Uporaba kartice na datoteko',
    'edit_payment_details' => 'Uredi podatke o plačilu',
    'token_billing' => 'Shrani podatke kartice',
    'token_billing_secure' => 'Podatki so varno shranjeni z: :link',
    'support' => 'Podpora',
    'contact_information' => 'Kontaktni podatki',
    '256_encryption' => '256-Bitno šifriranje',
    'amount_due' => 'Znesek do',
    'billing_address' => 'Naslov za pošiljanje računa',
    'billing_method' => 'Računsko sredstvo',
    'order_overview' => 'Pregled naročila',
    'match_address' => '*Naslov se mora ujemati z naslovom, povezanim s kreditno kartico.',
    'click_once' => '*Prosim klikni "Plačaj zdaj" samo enkrat - Transakcija lahko traja tudi do 1 minute.',
    'invoice_footer' => 'Noga računa',
    'save_as_default_footer' => 'Shrani kot privzeta noga',
    'token_management' => 'Upravitelj žetonov',
    'tokens' => 'Žetoni',
    'add_token' => 'Dodaj žeton',
    'show_deleted_tokens' => 'Prikaži odstranjene žetone',
    'deleted_token' => 'Žeton uspešno odstranjen',
    'created_token' => 'Žeton uspešno ustvarjen',
    'updated_token' => 'Žeton uspešno posodobljen',
    'edit_token' => 'Uredi žeton',
    'delete_token' => 'Odstrani žeton',
    'token' => 'Žeton',
    'add_gateway' => 'Dodaj prehod',
    'delete_gateway' => 'Odstrani prehod',
    'edit_gateway' => 'Uredi prehod',
    'updated_gateway' => 'Prehod uspešno obnovljen',
    'created_gateway' => 'Prehod uspešno ustvarjen',
    'deleted_gateway' => 'Prehod uspešno odstranjen',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Kreditna kartica',
    'change_password' => 'Spremeni geslo',
    'current_password' => 'Trenutno geslo',
    'new_password' => 'Novo geslo',
    'confirm_password' => 'Potrdi geslo',
    'password_error_incorrect' => 'Trenutno geslo je napačno',
    'password_error_invalid' => 'Novo geslo je napačno',
    'updated_password' => 'Geslo uspešno posodobljeno',
    'api_tokens' => 'API žetoni',
    'users_and_tokens' => 'Uporabniki in Žetoni',
    'account_login' => 'Prijava v račun',
    'recover_password' => 'Obnovite vaše geslo',
    'forgot_password' => 'Ste pozabili geslo?',
    'email_address' => 'E-poštni naslov',
    'lets_go' => 'Pojdimo',
    'password_recovery' => 'Obnovitev gesla',
    'send_email' => 'Pošlji e-pošto',
    'set_password' => 'Nastavi geslo',
    'converted' => 'Pretvorjeno',
    'email_approved' => 'Pošlji e-pošto ob <b>potrjenem</b> predračunu',
    'notification_quote_approved_subject' => 'Stranka :client je potrdila predračun :invoice',
    'notification_quote_approved' => 'Stranka :client je potrdila predračun :invoice v znesku :amount.',
    'resend_confirmation' => 'Znova pošlji potrditveno e-pošto',
    'confirmation_resent' => 'Potrditvena e-pošto je bila poslana.',
    'gateway_help_42' => ':link za BitPay.<br/>Opozorilo: Uporabite Legacy API Key, ne API žeton.',
    'payment_type_credit_card' => 'Kreditna kartica',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Baza znanja',
    'partial' => 'Delno plačilo/polog',
    'partial_remaining' => ':partial od :balance',
    'more_fields' => 'Več polj',
    'less_fields' => 'Manj polj',
    'client_name' => 'Ime stranke',
    'pdf_settings' => 'PDF nastavitve',
    'product_settings' => 'izdelka',
    'auto_wrap' => 'Samodejni prelom vrstic',
    'duplicate_post' => 'Opozirilo: Prejšnja stran je bila oddana dvakrat. Druga oddaja je bila prezrta.',
    'view_documentation' => 'Ogled dokumentacije',
    'app_title' => 'Brezplačni spletni Open-Source sistem za fakturiranje',
    'app_description' => 'InvoiceNinja je brezplačna, open-source rešitev za fakturiranje in izdajo računov. Z Invoice Ninjo lahko enostavno ustvarite in pošiljate čudovite račune z katere koli naprave, ki ima dostop do spleta. Vaše stranke lahko tiskajo  račune, jih prenesejo v PDF obliki, in tudi ti plačujejo preko spleta.',
    'rows' => 'vrstic',
    'www' => 'www',
    'logo' => 'Logotip',
    'subdomain' => 'Poddomena',
    'provide_name_or_email' => 'Vnesite ime ali e-poštni naslov',
    'charts_and_reports' => 'Grafikoni in Poročila',
    'chart' => 'Grafikon',
    'report' => 'Poročilo',
    'group_by' => 'Združi v skupino',
    'paid' => 'Plačano',
    'enable_report' => 'Poročilo',
    'enable_chart' => 'Grafikon',
    'totals' => 'Vsote',
    'run' => 'Zagon',
    'export' => 'Izvoz',
    'documentation' => 'Dokumentacija',
    'zapier' => 'Zapier',
    'recurring' => 'Ponavlj. računi',
    'last_invoice_sent' => 'Zadnji poslan račun: :date',
    'processed_updates' => 'Posodobitev uspešno izvedena',
    'tasks' => 'Opravila',
    'new_task' => 'Novo opravilo',
    'start_time' => 'Začetek',
    'created_task' => 'Opravilo uspešno ustvarjeno',
    'updated_task' => 'Opravilo uspešno posodobljeno',
    'edit_task' => 'Uredi opravilo',
    'clone_task' => 'Zapri opravilio',
    'archive_task' => 'Arhiviraj opravilo',
    'restore_task' => 'Obnovi opravilo',
    'delete_task' => 'Odstrani opravilo',
    'stop_task' => 'Končaj opravilo',
    'time' => 'Čas',
    'start' => 'Začetek',
    'stop' => 'Končaj',
    'now' => 'Zdaj',
    'timer' => 'Merilec časa',
    'manual' => 'Ročno',
    'date_and_time' => 'Datum in Čas',
    'second' => 'Sekunda',
    'seconds' => 'Sekund',
    'minute' => 'Minuta',
    'minutes' => 'Minut',
    'hour' => 'Ura',
    'hours' => 'Ur',
    'task_details' => 'Podrobnosti opravila',
    'duration' => 'Trajanje',
    'time_log' => 'Časovni Dnevnik',
    'end_time' => 'Čas zaključka',
    'end' => 'Konec',
    'invoiced' => 'Fakturirano',
    'logged' => 'Prijavljeno',
    'running' => 'V teku',
    'task_error_multiple_clients' => 'Opravilo ne sme pripadati drugi stranki',
    'task_error_running' => 'Najprej ustavite storitve prosim.',
    'task_error_invoiced' => 'Opravila so bila že zaračunana',
    'restored_task' => 'Opravilo uspešno obnovljeno',
    'archived_task' => 'Opravilo uspešno arhivirano',
    'archived_tasks' => 'Število uspešno odstranjenih opravil: :count',
    'deleted_task' => 'Opravilo uspešno odstranjeno',
    'deleted_tasks' => 'Število uspešno odstranjenih opravil: :count tasks',
    'create_task' => 'Vnesi opravilo',
    'stopped_task' => 'Opravilo uspešno ustavljeno',
    'invoice_task' => 'Fakturiraj opravilo',
    'invoice_labels' => 'Oznake na računu',
    'prefix' => 'Predpona',
    'counter' => 'Števec',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link za prijavo za Dwolla',
    'partial_value' => 'Mora biti večje od nič in manjše od celotnega zneska',
    'more_actions' => 'Več dejanj',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Nadgradi zdaj!',
    'pro_plan_feature1' => 'Ustvari neomejeno Strank',
    'pro_plan_feature2' => 'Dostop do 10 čudovitih modelov računa',
    'pro_plan_feature3' => 'URL po meri - "VasePodjetje.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Odstrani "Narejeno z uporabo programa Invoice Ninja"',
    'pro_plan_feature5' => 'Multi-uporabniški dostop in sledenje aktivnosti',
    'pro_plan_feature6' => 'Ustvari predračune in proforma račune',
    'pro_plan_feature7' => 'Prilagodite polja računa in oštevilčevanje',
    'pro_plan_feature8' => 'Možnost za dodajanje PDF priponk v e-poštna sporočila strankam',
    'resume' => 'Nadaljuj',
    'break_duration' => 'Prekini',
    'edit_details' => 'Uredi podrobnosti',
    'work' => 'Delo',
    'timezone_unset' => 'Please :link to set your timezone',
    'click_here' => 'klikni tukaj',
    'email_receipt' => 'Pošlji račun stranki',
    'created_payment_emailed_client' => 'Uspešno ustvarjeno plačilo in poslano stranki',
    'add_company' => 'Dodaj podjetje',
    'untitled' => 'Neimenovano',
    'new_company' => 'Novo podjetje',
    'associated_accounts' => 'Uspešno povezani računi',
    'unlinked_account' => 'Povezava računov prekinjena',
    'login' => 'Prijava',
    'or' => 'ali',
    'email_error' => 'Prišlo je do napake pri pošiljanju elektronske pošte',
    'confirm_recurring_timing' => 'Opozorilo: e-pošta bo poslana ob začetku ure.',
    'confirm_recurring_timing_not_sent' => 'Opomba: računi se ustvarijo na začetku ure.',
    'payment_terms_help' => 'Privzeto bo izbran ta <b>rok plačila</b>.',
    'unlink_account' => 'Prekini povezavo računa',
    'unlink' => 'Prekini povezavo',
    'show_address' => 'Prikaži naslov',
    'show_address_help' => 'Stranka mora vnesti naslov za račun',
    'update_address' => 'Posodobi naslov',
    'update_address_help' => 'Posodobi naslov stranke z predloženimi podatki',
    'times' => 'Čas',
    'set_now' => 'Nastavi trenuten čas',
    'dark_mode' => 'Temen način',
    'dark_mode_help' => 'Uporabi temen stil za stranske vrstice',
    'add_to_invoice' => 'Dodaj k računu :invoice',
    'create_new_invoice' => 'Ustvari nov račun',
    'task_errors' => 'Prosim popravite prekrivajoče časove',
    'from' => 'Od',
    'to' => 'Do',
    'font_size' => 'Velikost pisave',
    'primary_color' => 'Osnovna barva',
    'secondary_color' => 'Sekundarna barva',
    'customize_design' => 'Izgled po meri',
    'content' => 'Vsebina',
    'styles' => 'Stili',
    'defaults' => 'Privzeto',
    'margins' => 'Robovi',
    'header' => 'Glava',
    'footer' => 'Noga',
    'custom' => 'Po meri',
    'invoice_to' => 'Račun za',
    'invoice_no' => 'Št. računa',
    'quote_no' => 'Predračun št.',
    'recent_payments' => 'Nedavna plačila',
    'outstanding' => 'Odprte postavke',
    'manage_companies' => 'Upravljanj podjetja',
    'total_revenue' => 'Skupni prihodki',
    'current_user' => 'Trenutni uporabnik',
    'new_recurring_invoice' => 'Nov ponavljajoči račun',
    'recurring_invoice' => 'Ponavljajoči račun',
    'new_recurring_quote' => 'Nov ponavljajoči predračun',
    'recurring_quote' => 'Ponavljajoči predračun',
    'recurring_too_soon' => 'Prezgodaj je, da bi ustvarili naslednji račun. Naslednjič je predviden :date',
    'created_by_invoice' => 'Naredil: :invoice',
    'primary_user' => 'Primarni uporabnik',
    'help' => 'Pomoč',
    'customize_help' => '<p>Uporabljamo :pdfmake_link, da deklarativno definiramo oblike računov. Pdfmake :playground_link je odličen način za ogled knjižnice v akciji.</p>
<p>Če potrebujete pomoč nam pošljite vprašanje na :forum_link z zasnovo, ki jo uporabljate.</p>',
    'playground' => 'peskovnik',
    'support_forum' => 'forum za podporo',
    'invoice_due_date' => 'Veljavnost',
    'quote_due_date' => 'Veljavnost',
    'valid_until' => 'Veljavnost',
    'reset_terms' => 'Ponastavi pogoje',
    'reset_footer' => 'Ponastavi nogo',
    'invoice_sent' => ':count račun poslan',
    'invoices_sent' => ':count računi poslani ',
    'status_draft' => 'Osnutek',
    'status_sent' => 'Poslano',
    'status_viewed' => 'Ogledano',
    'status_partial' => 'Delno plačano',
    'status_paid' => 'Plačano',
    'status_unpaid' => 'Neplačano',
    'status_all' => 'Vse',
    'show_line_item_tax' => 'Prikaži <b>davke v vrstici</b>',
    'iframe_url' => 'Spletna stran',
    'iframe_url_help1' => 'Kopiraj kodo na vašo spletno stran.',
    'iframe_url_help2' => 'Funkcijo lahko preizkusite s klikom na "Prikaži kot prejemnik" na računu.',
    'auto_bill' => 'Samodejno plačilo',
    'military_time' => '24 urni čas',
    'last_sent' => 'Zadnji poslan',
    'reminder_emails' => 'Opomini prek e-pošte',
    'quote_reminder_emails' => 'Opomnik preko e-pošte',
    'templates_and_reminders' => 'Predloge in opomini',
    'subject' => 'Naslov',
    'body' => 'Vsebina',
    'first_reminder' => 'Prvi opomin',
    'second_reminder' => 'Drugi opomin',
    'third_reminder' => 'Tretji opomin',
    'num_days_reminder' => 'Dnevi zamude',
    'reminder_subject' => 'Opomin: račun :invoice od :account',
    'reset' => 'Ponastavi',
    'invoice_not_found' => 'Zahtevan račun ni na voljo',
    'referral_program' => 'Program napotnice',
    'referral_code' => 'URL Naslov napotnice',
    'last_sent_on' => 'Zadnji poslani: :date',
    'page_expire' => 'Ta stran bo kmalu potekla, :click_here za nadaljevanje dela',
    'upcoming_quotes' => 'Prihajajoči predračuni',
    'expired_quotes' => 'Potekli predračuni',
    'sign_up_using' => 'Prijavi se z',
    'invalid_credentials' => 'Prijava se ne ujema z našimi podatki',
    'show_all_options' => 'Pokaži vse opcije',
    'user_details' => 'Podrobnosti uporabnika',
    'oneclick_login' => 'Povezan račun',
    'disable' => 'Onemogoči',
    'invoice_quote_number' => 'Številke računov in predračunov',
    'invoice_charges' => 'Doplačila k računu',
    'notification_invoice_bounced' => 'Računa :invoice ni bilo možno dostaviti na: :contact.',
    'notification_invoice_bounced_subject' => 'Računa :invoice ni bilo možno dostaviti',
    'notification_quote_bounced' => 'Predračuna :invoice ni bilo možno dostaviti na/k :contact.',
    'notification_quote_bounced_subject' => 'Predračuna :invoice ni bilo možno dostaviti',
    'custom_invoice_link' => 'Povezava po meri',
    'total_invoiced' => 'Skupni računi',
    'open_balance' => 'Saldo',
    'verify_email' => 'Za potrditev vašega e-poštni naslova obiščite povezavo v poslani e-pošti, .',
    'basic_settings' => 'Osnovne nastavitve',
    'pro' => 'Pro',
    'gateways' => 'Plačilni prehodi',
    'next_send_on' => 'Naslednje pošiljanje: :date',
    'no_longer_running' => 'Ta račun je označen za zagon',
    'general_settings' => 'Splošne nastavitve',
    'customize' => 'Prilagodi po meri',
    'oneclick_login_help' => 'Povežite račun za prijavo brez gesla',
    'referral_code_help' => 'Zaslužite z deljenjen naše aplikacijo na spletu',
    'enable_with_stripe' => 'Omogoči | Zahteva Stripe',
    'tax_settings' => 'Davčne dastavitve',
    'create_tax_rate' => 'Dodaj davčno stopnjo',
    'updated_tax_rate' => 'Davčna stopnja uspešno posodobljena',
    'created_tax_rate' => 'Davčna stopnja uspešno ustvarjena',
    'edit_tax_rate' => 'Uredi davčno stopnjo',
    'archive_tax_rate' => 'Arhiviraj davčno stopnjo',
    'archived_tax_rate' => 'Davčna stopnja uspešno arhivirana',
    'default_tax_rate_id' => 'Privzeta davčna stopnja',
    'tax_rate' => 'Davčna stopnja',
    'recurring_hour' => 'Ura pošiljanja ponavljajočega računa',
    'pattern' => 'Vzorec',
    'pattern_help_title' => 'Vzorec - Pomoč',
    'pattern_help_1' => 'Z določitvijo vzorca ustvari številke meri',
    'pattern_help_2' => 'Veljavne spremenljivke:',
    'pattern_help_3' => 'Na primer, :example bi bil pretvorjen v :value',
    'see_options' => 'Poglej možnosti',
    'invoice_counter' => 'Števec za račun',
    'quote_counter' => 'Števec predračunov',
    'type' => 'Tip',
    'activity_1' => ':user je ustvaril stranko :client',
    'activity_2' => ':user je arhiviraj stranko :client',
    'activity_3' => ':user je odstranil stranko :client',
    'activity_4' => ':user je ustvaril račun :invoice',
    'activity_5' => ':user je posodobil račun :invoice',
    'activity_6' => ':user je račun :invoice za :client poslal osebi :contact',
    'activity_7' => ':contact si je ogledal račun :invoice za :client',
    'activity_8' => ':user je arhiviral račun :invoice',
    'activity_9' => ':user je odstranil račun :invoice',
    'activity_10' => ':contact je vnesel plačilo :payment v znesku :payment_amount na računu :invoice za :client',
    'activity_11' => ':user je posodobil plačilo :payment',
    'activity_12' => ':user je arhiviral plačilo :payment',
    'activity_13' => ':user je odstranil :payment',
    'activity_14' => ':user je vnesel :credit dobropis',
    'activity_15' => ':user je posodobil :credit dobropis',
    'activity_16' => ':user je arhiviral :credit dobropis',
    'activity_17' => ':user je odstranil :credit dobropis',
    'activity_18' => ':user je ustvaril predračun :quote',
    'activity_19' => ':user je posodobil predračun :quote',
    'activity_20' => ':user je predračun :quote za :client poslal osebi :contact',
    'activity_21' => ':contact je pogledal predračun :quote',
    'activity_22' => ':user je arhiviral predračun :quote',
    'activity_23' => ':user je odstranil predračun :quote',
    'activity_24' => ':user je obnovil predračun :quote',
    'activity_25' => ':user je obnovil račun :invoice',
    'activity_26' => ':user je obnovil stranko :client',
    'activity_27' => ':user je obnovil plačilo :payment',
    'activity_28' => ':user je obnovil dobropis :credit',
    'activity_29' => ':contact je potrdil predračun :quote za :client',
    'activity_30' => ':user je ustvaril prodajalca :vendor',
    'activity_31' => ':user je arhiviral prodajalca :vendor',
    'activity_32' => ':user je odstranil prodajalca :vendor',
    'activity_33' => ':user je obnovil prodajalca :vendor',
    'activity_34' => ':user je vnesel strošek :expense',
    'activity_35' => ':user je arhiviral strošek :expense',
    'activity_36' => ':user je izbrisal strošek :expense',
    'activity_37' => ':user je obnovil strošek :expense',
    'activity_42' => ':user je vnesel opravilo :task',
    'activity_43' => ':user je posodobil opravilo :task',
    'activity_44' => ':user je arhiviral opravilo :task',
    'activity_45' => ':user je izbrisal opravilo :task',
    'activity_46' => ':user je obnovil opravilo :task',
    'activity_47' => ':user je posodobil opravilo :expense',
    'activity_48' => ':user je posodobil zahtevek :ticker',
    'activity_49' => ':user je zaprl zahtevek :ticket',
    'activity_50' => ':user je združil zahtevek :ticket',
    'activity_51' => ':user je razdružil zahtevek :ticket',
    'activity_52' => ':contact je odprl zahtevek :ticket',
    'activity_53' => ':contact je ponovno odprl zahtevek :ticket',
    'activity_54' => ':user je ponovno odprl zahtevek :ticket',
    'activity_55' => ':contact je odgovoril na zahtevek :ticket',
    'activity_56' => ':user si je ogledal zahtevek :ticket',

    'payment' => 'Plačilo',
    'system' => 'Sistem',
    'signature' => 'Podpis v e-pošti',
    'default_messages' => 'Privzeta sporočila',
    'quote_terms' => 'Pogoji predračuna',
    'default_quote_terms' => 'Privzeti pogoji predračuna',
    'default_invoice_terms' => 'Privzeti pogoji računa',
    'default_invoice_footer' => 'Privzata noga računa',
    'quote_footer' => 'Noga predračuna',
    'free' => 'Brezplačno',
    'quote_is_approved' => 'Uspešno odobreno',
    'apply_credit' => 'Potrdi dobropis',
    'system_settings' => 'Sistemske nastavitve',
    'archive_token' => 'Arhiviraj žeton',
    'archived_token' => 'Žeton uspešno arhiviran',
    'archive_user' => 'Ahriviraj uporabnika',
    'archived_user' => 'Uporabnik uspešno arhiviran',
    'archive_account_gateway' => 'Odstrani Prehod',
    'archived_account_gateway' => 'Prehod uspešno akhiviran',
    'archive_recurring_invoice' => 'Arhiviraj ponavljajoči račun',
    'archived_recurring_invoice' => 'Ponavljajoči račun uspešno arhiviran',
    'delete_recurring_invoice' => 'Odstrani ponavljajoči račun',
    'deleted_recurring_invoice' => 'Ponavljajoči račun uspešno odstranjen',
    'restore_recurring_invoice' => 'Obnovi ponavljajoči račun',
    'restored_recurring_invoice' => 'Ponavljajoči račun uspešno obnovljen',
    'archive_recurring_quote' => 'Arhiviraj ponavljajoči predračun',
    'archived_recurring_quote' => 'Ponavljajoči predračun uspešno arhiviran',
    'delete_recurring_quote' => 'Izbriši ponavljajoči predračun',
    'deleted_recurring_quote' => 'Ponavljajoči predračun uspešno odstranjen',
    'restore_recurring_quote' => 'Obnovi ponavljajoči predračun',
    'restored_recurring_quote' => 'Ponavljajoči predračun uspešno obnovljen',
    'archived' => 'Arhivirano',
    'untitled_account' => 'Neimenovano podjetje',
    'before' => 'Pred',
    'after' => 'Po',
    'reset_terms_help' => 'Ponastavi privzete pogoje računa',
    'reset_footer_help' => 'Ponastavi privzeto nogo računa',
    'export_data' => 'Izvozi podatke',
    'user' => 'Uporabnik',
    'country' => 'Država',
    'include' => 'Vsebuje',
    'logo_too_large' => 'Vaš logotip je :size. Za boljše PDF delovanje priporočamo, da naložite datoteko s sliko z manj kot 200KB',
    'import_freshbooks' => 'Uvozi z FreshBooks',
    'import_data' => 'Uvozi podatke',
    'source' => 'Izvor',
    'csv' => 'CSV',
    'client_file' => 'Datoteka strank',
    'invoice_file' => 'Datoteka računov',
    'task_file' => 'Datoteka opravil',
    'no_mapper' => 'Neveljavno kartiranje za datoteko',
    'invalid_csv_header' => 'Neveljavna CSV Glava',
    'client_portal' => 'Portal za stranke',
    'admin' => 'Skrbnik',
    'disabled' => 'Onemogočeno',
    'show_archived_users' => 'Prikaži arhivirane uporabnike',
    'notes' => 'Opis',
    'invoice_will_create' => 'račun bo ustvarjen',
    'invoices_will_create' => 'računi bodo ustvarjeni',
    'failed_to_import' => 'Zapisov ni bilo mogoče uvoziti, bodisi že obstajajo ali pa manjkajo zahtevana polja.',
    'publishable_key' => 'Ključ za objavo',
    'secret_key' => 'Skrivni ključ',
    'missing_publishable_key' => 'Nastavite Stripe objavni ključ za izboljšan postopek odjave',
    'email_design' => 'Stil e-pošte',
    'due_by' => 'Zapadlost: :date',
    'enable_email_markup' => 'Omogoči označbe.',
    'enable_email_markup_help' => 'Olajšajte strankam plačevanje z dodajanjem schema.org označb v vašo e-pošto.',
    'template_help_title' => 'Pomoč za predloge',
    'template_help_1' => 'Razpoložljive spremenljivke:',
    'email_design_id' => 'Stil e-pošte',
    'email_design_help' => 'Naredi e-pošto videti bolj profesionalno z uporabo HTML postavitve.',
    'plain' => 'Navadno',
    'light' => 'Svetlo',
    'dark' => 'Temno',
    'industry_help' => 'Uporablja se za primerjavo s podjetjim podobne velikosti in panoge.',
    'subdomain_help' => 'Nastavite pod domeno ali prikažite račun na vaši spletni strani.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Za dinamično dodelitev številke računa določite predpono ali uporabite vzorec po meri.',
    'quote_number_help' => 'Določi predpono ali lasten vzorec za določitev številk predračunov.',
    'custom_client_fields_helps' => 'Dodaj polje pri ustvarjanju stranke ter neobvezen prikaz tega polja na PDF.',
    'custom_account_fields_helps' => 'Dodaj oznako in vrednost v območje podatkov podjetja v PDF.',
    'custom_invoice_fields_helps' => 'Dodaj polje pri ustvarjanju računa ter neobvezen prikaz tega polja na PDF.',
    'custom_invoice_charges_helps' => 'Pri ustvarjanju računa, ki vključuje stroške v skupnem znesku, dodaj polje.',
    'token_expired' => 'Potrditveni žeton je potekel. Prosim poskusite ponovno.',
    'invoice_link' => 'Pot do Računa',
    'button_confirmation_message' => 'Kliknite, da potrdite svoj e-poštni naslov.',
    'confirm' => 'Potrdi',
    'email_preferences' => 'Nastavitve e-pošte',
    'created_invoices' => 'Število uspešno vnešenih računov: :count',
    'next_invoice_number' => 'Št. naslednjega računa je :number.',
    'next_quote_number' => 'Naslednja št. predračuna je :number.',
    'days_before' => 'dan pred',
    'days_after' => 'dan po',
    'field_due_date' => 'Zapadlost računa',
    'field_invoice_date' => 'Datum računa',
    'schedule' => 'Urnik',
    'email_designs' => 'Stili e-pošte',
    'assigned_when_sent' => 'Dodeljen ko je poslan',
    'white_label_purchase_link' => 'Kupi White label licenco',
    'expense' => 'Strošek',
    'expenses' => 'Stroški',
    'new_expense' => 'Vnesi strošek',
    'enter_expense' => 'Vnesi strošek',
    'vendors' => 'Prodajalci',
    'new_vendor' => 'Nov prodajalec',
    'payment_terms_net' => 'Neto',
    'vendor' => 'Prodajalec',
    'edit_vendor' => 'Uredi prodajalca',
    'archive_vendor' => 'Arhiviraj prodajalca',
    'delete_vendor' => 'Odstrani prodajalca',
    'view_vendor' => 'Ogled prodajalca',
    'deleted_expense' => 'Strošek uspešno odstranjen',
    'archived_expense' => 'Strošek uspešno arhiviran',
    'deleted_expenses' => 'Stroški uspešno odstranjeni',
    'archived_expenses' => 'Stroški uspešno arhivirani',
    'expense_amount' => 'Znesek stroška',
    'expense_balance' => 'Saldo stroška',
    'expense_date' => 'Datum stroška',
    'expense_should_be_invoiced' => 'Ali naj bo ta strošek na računu?',
    'public_notes' => 'Javni zaznamki',
    'invoice_amount' => 'Znesek računa',
    'exchange_rate' => 'Menjalni tečaj',
    'yes' => 'Da',
    'no' => 'Ne',
    'should_be_invoiced' => 'Bo fakturiran',
    'view_expense' => 'Ogled stroška # :expense',
    'edit_expense' => 'Uredi strošek',
    'archive_expense' => 'Arhiviraj strošek',
    'delete_expense' => 'Odstrani strošek',
    'view_expense_num' => 'Strošek # :expense',
    'updated_expense' => 'Strošek uspešno posodobljen',
    'created_expense' => 'Strošek uspešno vnešen',
    'enter_expense' => 'Vnesi strošek',
    'view' => 'Ogled',
    'restore_expense' => 'Obnovi strošek',
    'invoice_expense' => 'Strošek računa',
    'expense_error_multiple_clients' => 'Stroški ne morejo pripadati različnim strankam.',
    'expense_error_invoiced' => 'Strošek je že bil fakturiran',
    'convert_currency' => 'Pretvori valuto',
    'num_days' => 'Število dni',
    'create_payment_term' => 'Ustvari plačini Pogoj',
    'edit_payment_terms' => 'Uredi plačilni Pogoj',
    'edit_payment_term' => 'Uredi plačilni pogoj',
    'archive_payment_term' => 'Arhiviraj plačini Pogoj',
    'recurring_due_dates' => 'Zapadlost ponavljajočih računov',
    'recurring_due_date_help' => '<p>Automatically sets a due date for the invoice.</p>
        <p>Invoices on a monthly or yearly cycle set to be due on or before the day they are created will be due the next month. Invoices set to be due on the 29th or 30th in months that don\'t have that day will be due the last day of the month.</p>
        <p>Invoices on a weekly cycle set to be due on the day of the week they are created will be due the next week.</p>
        <p>For example:</p>
        <ul>
          <li>Today is the 15th, due date is 1st of the month. The due date should likely be the 1st of the next month.</li>
          <li>Today is the 15th, due date is the last day of the month. The due date will be the last day of the this month.
</li>
          <li>Today is the 15th, due date is the 15th day of the month. The due date will be the 15th day of <strong>next</strong> month.
</li>
          <li>Today is the Friday, due date is the 1st Friday after. The due date will be next Friday, not today.
</li>
        </ul>',
    'due' => 'Do',
    'next_due_on' => 'Zapadlost naslednjega: :date',
    'use_client_terms' => 'Uporabi pogoje stranke',
    'day_of_month' => ':ordinal dan v mesecu',
    'last_day_of_month' => 'Zadnji dan v mesecu',
    'day_of_week_after' => ':ordinal :day po',
    'sunday' => 'Nedelja',
    'monday' => 'Ponedeljek',
    'tuesday' => 'Torek',
    'wednesday' => 'Sreda',
    'thursday' => 'Četrtek',
    'friday' => 'Petek',
    'saturday' => 'Sobota',
    'header_font_id' => 'Pisava glave',
    'body_font_id' => 'Pisava vsebine',
    'color_font_help' => 'Opomba: osnovna barva in pisava se uporablja tudi v portalu za stranke in v prilagojenih e-poštnih sporočilih.',
    'live_preview' => 'Takojšen predogled',
    'invalid_mail_config' => 'E-pošte ni bilo mogoče poslati. Preverite, da so e-poštne nastavitve pravilne.',
    'invoice_message_button' => 'Za ogled vašega računa v znesku :amount, klikni na gumb spodaj.',
    'quote_message_button' => 'Za ogled vašega predračuna v znesku :amount, kliknite na gumb spodaj.',
    'payment_message_button' => 'Zahvaljujemo se vam za plačilo v znesku :amount.',
    'payment_type_direct_debit' => 'Neposredena bremenitev',
    'bank_accounts' => 'Kreditne kartice in banke',
    'add_bank_account' => 'Dodaj bančni račun',
    'setup_account' => 'Nastavi račun',
    'import_expenses' => 'Uvozi stroške',
    'bank_id' => 'Banka',
    'integration_type' => 'Tip integracije',
    'updated_bank_account' => 'Bančni račun uspešno posodobljen',
    'edit_bank_account' => 'Uredi bančni račun',
    'archive_bank_account' => 'Arhiviraj bančni račun',
    'archived_bank_account' => 'Bančni račun uspešno arhiviran',
    'created_bank_account' => 'Bančni račun uspešno vnešen',
    'validate_bank_account' => 'Potrdi bančni račun',
    'bank_password_help' => 'Vaše geslo je varno posredovano in nikoli shranjeno na naših strežnikih.',
    'bank_password_warning' => 'Opozorilo: vaše geslo je lahko posredovano kot golo besedilo. Priporočamo uprabo HTTPS.',
    'username' => 'Uporabniško ime',
    'account_number' => 'Št. računa',
    'account_name' => 'Ime računa',
    'bank_account_error' => 'Podrobnosti o računu ni bilo mogoče pridobiti. Preverite poverilnice.',
    'status_approved' => 'Potrjeno',
    'quote_settings' => 'Nastavitve predračunov',
    'auto_convert_quote' => 'Samodejna Pretvorba',
    'auto_convert_quote_help' => 'Samodejno pretvori predračun v račun, ki ga stranka potrdi.',
    'validate' => 'Potrdi',
    'info' => 'Info',
    'imported_expenses' => 'Uspešno vnešeni prodajalci: :count_vendors in stroški: :count_expenses',
    'iframe_url_help3' => 'Opomba: če nameravate sprejemati spletna plačila predlagamo, da na vaši strani omogočite HTTPS.',
    'expense_error_multiple_currencies' => 'Strošek ne sme imeti dveh valut.',
    'expense_error_mismatch_currencies' => 'Valuta stranke ni enaka valuti stroška.',
    'trello_roadmap' => 'Trello načrt',
    'header_footer' => 'Glava/Noga',
    'first_page' => 'Prva stran',
    'all_pages' => 'Vse strani',
    'last_page' => 'Zadnja stran',
    'all_pages_header' => 'Prikaži glavo na',
    'all_pages_footer' => 'Prikaži nogo na',
    'invoice_currency' => 'Valuta računa',
    'enable_https' => 'Pri spletnem sprejemanju kreditnih kartic močno priporočamo uporabo HTTPS.',
    'quote_issued_to' => 'Predračun izdan na',
    'show_currency_code' => 'Valuta',
    'free_year_message' => 'Vaš račun je bil brezplačno nadgrajen v pro paket.',
    'trial_message' => 'Vaš račun bo prejel dva tedna brezplačne uporabe našega pro paketa.',
    'trial_footer' => 'Vaš brezplačni pro paket še velja :count dni, :link da nadgradite vaš paket.',
    'trial_footer_last_day' => 'Danes poteče vaš brezplačni pro paket, :link da ga podaljšate ali nadgradite.',
    'trial_call_to_action' => 'Začni brezplačno poskusno obdobje',
    'trial_success' => 'Dva tedensko brezplačno poskusno obdobje uspešno omogočeno.',
    'overdue' => 'Zapadlo',


    'white_label_text' => 'Za odstranitev Invoice Ninja znamke z računa in portala za stranke, zakupi enoletno "white Label" licenco v znesku $:price.',
    'user_email_footer' => 'Za spremembo e-poštnih obvestil obiščite :link',
    'reset_password_footer' => 'Če niste zahtevali ponastavitev gesla, nas prosim obvestite na naslov: :email',
    'limit_users' => 'To bo preseglo mejo :limit uporabnikov',
    'more_designs_self_host_header' => 'Pridobite 6 slogov za račun za samo $:price',
    'old_browser' => 'Prosim uporabi :link',
    'newer_browser' => 'novejši brskalnik',
    'white_label_custom_css' => ':link za $:price da omogočite lastne sloge za pomoč in podporo našega projekta',
    'bank_accounts_help' => 'Povežite bančni račun, če želite samodejno uvoziti stroške in ustvariti ponudnike. Podpira American Express in :link.',
    'us_banks' => '400+ bank v ZDA',

    'pro_plan_remove_logo' => ':link za odstranitev logotipa Invoice Ninja z vstopom v Pro Plan',
    'pro_plan_remove_logo_link' => 'Klikni tu',
    'invitation_status_sent' => 'Poslano',
    'invitation_status_opened' => 'Odprto',
    'invitation_status_viewed' => 'Ogledano',
    'email_error_inactive_client' => 'E-pošte se ne more pošiljati neaktivnim strankam',
    'email_error_inactive_contact' => 'E-pošte se ne more pošiljati neaktivnim kontaktom',
    'email_error_inactive_invoice' => 'E-pošte se ne more pošiljati neaktivnim računom',
    'email_error_inactive_proposal' => 'E-pošte ni mogoče poslati neaktivnim ponudbam',
    'email_error_user_unregistered' => 'Za pošiljanje e-pošte registrirajte vaš račun',
    'email_error_user_unconfirmed' => 'Za pošiljanje pošte potrdite svoj račun',
    'email_error_invalid_contact_email' => 'Neveljaven e-poštni naslov kontakta',

    'navigation' => 'Navigacija',
    'list_invoices' => 'Seznam računov',
    'list_clients' => 'Seznam strank',
    'list_quotes' => 'Seznam predračunov',
    'list_tasks' => 'Seznam opravil',
    'list_expenses' => 'Seznam stroškov',
    'list_recurring_invoices' => 'Seznam ponavljajočih računov',
    'list_payments' => 'Seznam računov',
    'list_credits' => 'Seznam dobropisov',
    'tax_name' => 'Ime davčne stopnje',
    'report_settings' => 'Nastavitve poročila',
    'search_hotkey' => 'bližnjica je /',

    'new_user' => 'Nov uporabnik',
    'new_product' => 'Nov izdelek',
    'new_tax_rate' => 'Nova davčna stopnja',
    'invoiced_amount' => 'Fakturiran znesek',
    'invoice_item_fields' => 'Polja postavk računa',
    'custom_invoice_item_fields_help' => 'Pri ustvarjanju postavke računa dodaj polje in na PDF dokumentu prikaži oznako in vrednost.',
    'recurring_invoice_number' => 'Ponavljajoče številke',
    'recurring_invoice_number_prefix_help' => 'Za ponavljajoče se račune določite predpono, ki se doda številki računa.',

    // Client Passwords
    'enable_portal_password' => 'Zaščiti račune z geslom',
    'enable_portal_password_help' => 'Omogoča da nastavite geslo za vsako osebo. Če je geslo nastavljeno, ga bo uporabnik moral vnesti pred ogledom računa.',
    'send_portal_password' => 'Samodejno nastavi',
    'send_portal_password_help' => 'Če geslo ni nastavljeno, bo ustvarjeno samodejno in se pošlje s prvim računom.',

    'expired' => 'Poteklo',
    'invalid_card_number' => 'Št. kreditne kartice ni veljavna.',
    'invalid_expiry' => 'Datum poteka ni veljaven.',
    'invalid_cvv' => 'CVV ni veljaven.',
    'cost' => 'Cena',
    'create_invoice_for_sample' => 'Opomba: ustvarite vaš prvi račun da boste tu videli predogled.',

    // User Permissions
    'owner' => 'Lastnik',
    'administrator' => 'Upravljalec',
    'administrator_help' => 'Dovoli uporabniku da upravlja z uporabniki, nastavitvami in vsemi zapisi',
    'user_create_all' => 'Ustvarja stranke, račune, itd.',
    'user_view_all' => 'Vidi stranke, račune, itd.',
    'user_edit_all' => 'Ureja stranke, račune, itd.',
    'gateway_help_20' => ':link za prijavo na Sage Pay.',
    'gateway_help_21' => ':link za prijavo na Sage Pay.',
    'partial_due' => 'Delno plačilo do',
    'restore_vendor' => 'Obnovi prodajalca',
    'restored_vendor' => 'Prodajalec uspešno obnovljen',
    'restored_expense' => 'Strošek uspešno obnovljen',
    'permissions' => 'Pravice',
    'create_all_help' => 'Dovoli uporabniku da ustvarja in ureja zapise',
    'view_all_help' => 'Dovoli uporabniku ogled zapisov, ki jih ni naredil',
    'edit_all_help' => 'Dovoli uporabniku urejanje zapisov, ki jih ni naredil',
    'view_payment' => 'Ogled plačila',

    'january' => 'Januar',
    'february' => 'Februar',
    'march' => 'Marec',
    'april' => 'April',
    'may' => 'Maj',
    'june' => 'Junij',
    'july' => 'Julij',
    'august' => 'August',
    'september' => 'September',
    'october' => 'Oktober',
    'november' => 'November',
    'december' => 'December',

    // Documents
    'documents_header' => 'Dokumenti:',
    'email_documents_header' => 'Dokumenti:',
    'email_documents_example_1' => 'Pripomočni račun.pdf',
    'email_documents_example_2' => 'Končna dobavljivost.zip',
    'quote_documents' => 'Dokumenti predračuna',
    'invoice_documents' => 'Dokumenti računa',
    'expense_documents' => 'Dokumenti stroška',
    'invoice_embed_documents' => 'Omogočeni dokumenti',
    'invoice_embed_documents_help' => 'V računu vključi pripete slike.',
    'document_email_attachment' => 'Pripni dokumente',
    'ubl_email_attachment' => 'Pripni UBL',
    'download_documents' => 'Prenesi dokumente (:size)',
    'documents_from_expenses' => 'Od stroškov:',
    'dropzone_default_message' => 'Odložite datoteke ali kliknite tukaj',
    'dropzone_default_message_disabled' => 'Nalaganje onemogočeno',
    'dropzone_fallback_message' => 'Vaš brskalnik ne podpira funkcije povleci in spusti.',
    'dropzone_fallback_text' => 'Prosimo uporabite obrazec spodaj za nalaganje datotek, kot v starih časih.',
    'dropzone_file_too_big' => 'Datoteke je prevelika ({{filesize}}MiB). Največja dovoljena velikost datoteke: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Datoteke tega tipa niso dovoljene.',
    'dropzone_response_error' => 'Odgovor strežnika: {{statusCode}} ',
    'dropzone_cancel_upload' => 'Prekliči nalaganje',
    'dropzone_cancel_upload_confirmation' => 'Ali ste pripričani da želite preklicati nalaganje?',
    'dropzone_remove_file' => 'Odstrani datoteko',
    'documents' => 'Dokumenti',
    'document_date' => 'Datum dokumenta',
    'document_size' => 'Velikost',

    'enable_client_portal' => 'Portal za stranke',
    'enable_client_portal_help' => 'Pokaži/skrij portal za stranke',
    'enable_client_portal_dashboard' => 'Nadzorna plošča',
    'enable_client_portal_dashboard_help' => 'Prikaži/skrij nadzorno ploščo v stranko portalu.',

    // Plans
    'account_management' => 'Upravljanje računa',
    'plan_status' => 'Trenuten paket',

    'plan_upgrade' => 'Nadgradi',
    'plan_change' => 'Spremeni paket',
    'pending_change_to' => 'Spremeni v',
    'plan_changes_to' => ':plan na :date',
    'plan_term_changes_to' => ':plan (:term) na :date',
    'cancel_plan_change' => 'Prekliči spremembo',
    'plan' => 'Plan',
    'expires' => 'Poteče',
    'renews' => 'Se obnovi',
    'plan_expired' => ':plan paket je potekel',
    'trial_expired' => ':plan poskusno obdobje se je končalo',
    'never' => 'Nikoli',
    'plan_free' => 'Brezplačen',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Podjetje',
    'plan_white_label' => 'Lastno gostovanje (White Labeled)',
    'plan_free_self_hosted' => 'Lastno gostovanje (Brezplačno)',
    'plan_trial' => 'Poskusno',
    'plan_term' => 'Izraz',
    'plan_term_monthly' => 'Mesečno',
    'plan_term_yearly' => 'Letno',
    'plan_term_month' => 'Mesec',
    'plan_term_year' => 'Leto',
    'plan_price_monthly' => '$:cena/Mesec',
    'plan_price_yearly' => '$:cena/Leto',
    'updated_plan' => 'Posodobljene nastavitve paketa',
    'plan_paid' => 'Obdobje se je pričelo',
    'plan_started' => 'Začetek paketa',
    'plan_expires' => 'paket poteče',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'Letna članarina v Invoice Ninja Pro paket.',
    'pro_plan_month_description' => 'Mesečna članarina v Invoice Ninja Pro paket.',
    'enterprise_plan_product' => 'Paket za podjetja',
    'enterprise_plan_year_description' => 'Letna članarina v Invoice Ninja Podjetniški paket.',
    'enterprise_plan_month_description' => 'Mesečna članarina v Invoice Ninja Podjetniški paket.',
    'plan_credit_product' => 'Dobropis',
    'plan_credit_description' => 'Dobropis za neuporabljeni čas',
    'plan_pending_monthly' => 'Preklom na mesečno na:',
    'plan_refunded' => 'Vračilo je bilo izvedeno.',

    'live_preview' => 'Takojšen predogled',
    'page_size' => '
Velikost strani',
    'live_preview_disabled' => 'Zaradi izrane pisave je takojšen predogled onemogočen',
    'invoice_number_padding' => 'Mašilo',
    'preview' => 'Predogled',
    'list_vendors' => 'Seznam prodajalcev',
    'add_users_not_supported' => 'Za dodtne uporabnike v vašem računu nadgradi na Podjetniški paket',
    'enterprise_plan_features' => 'Podjetniški paket omogoča več uporabnikov in priponk. :link za ogled celotnega seznama funkcij.',
    'return_to_app' => 'Nazaj na vrh',


    // Payment updates
    'refund_payment' => 'Vračilo plačila',
    'refund_max' => 'Maksimalno:',
    'refund' => 'Vračilo',
    'are_you_sure_refund' => 'Vračilo izbranih plačil?',
    'status_pending' => 'V teku',
    'status_completed' => 'Končano',
    'status_failed' => 'Ni uspelo',
    'status_partially_refunded' => 'Delno vrnjeno',
    'status_partially_refunded_amount' => ':amount vrnjeno',
    'status_refunded' => 'Vrnjeno',
    'status_voided' => 'Preklicano',
    'refunded_payment' => 'Vrnjeno plačilo',
    'activity_39' => ':user je preklical plačilo :payment v znesku :payment_amount',
    'activity_40' => ':user je vrnil :adjustment od plačila :payment v znesku :payment_amount',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Neznano',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Prejemaj bančna nakazila iz ZDA',
    'stripe_ach_help' => 'Podporo za ACH je ravno tako potrebno omogočiti v :link.',
    'ach_disabled' => 'Za neposredno bremenitev je nastavljen drug prehod.',

    'plaid' => 'Plaid',
    'client_id' => 'Id stranke',
    'secret' => 'Skrivnost',
    'public_key' => 'Ključ za objavo',
    'plaid_optional' => '(neobvezno)',
    'plaid_environment_help' => 'Če uporabiš testni ključ Stripe, bo uporabljeno Plaidovo razvojno okolje (tartan).',
    'other_providers' => 'Ostali ponudniki',
    'country_not_supported' => 'Ta država ni podprta.',
    'invalid_routing_number' => 'Številka poti ni veljavna.',
    'invalid_account_number' => 'Št. računa ni veljavna.',
    'account_number_mismatch' => 'Številke na računu se ne ujemajo.',
    'missing_account_holder_type' => 'Prosim izberite posameznika ali podjetje.',
    'missing_account_holder_name' => 'Prosim vnesi ime lastnika računa',
    'routing_number' => 'Št. poti',
    'confirm_account_number' => 'Potrdi številko računa',
    'individual_account' => 'Individualni račun',
    'company_account' => 'Podjetniški račun',
    'account_holder_name' => 'Lastnik računa',
    'add_account' => 'Ustvari račun',
    'payment_methods' => 'Plačilno sredstvo',
    'complete_verification' => 'Dokončaj preverjanje',
    'verification_amount1' => 'Znesek 1',
    'verification_amount2' => 'Znesek 2',
    'payment_method_verified' => 'Preverjanje uspešno zaključeno',
    'verification_failed' => 'Preverjanje ni uspelo',
    'remove_payment_method' => 'Odstrani plačilno sredstvo',
    'confirm_remove_payment_method' => 'Ali ste prepričani da želite odstraniti to plačilno sredstvo?',
    'remove' => 'Odstrani',
    'payment_method_removed' => 'Odstrani plačilno sredstvo.',
    'bank_account_verification_help' => 'Na vaš račun smo izvršili dve vplačili z opisom "VERIFICATION". Trajalo bo približno 1-2 delovna dni, da bo transakcija vidna na izpisku. Prosim vnesite zneske spodaj.',
    'bank_account_verification_next_steps' => 'Na vaš račun smo izvršili dve vplačili z opisom "VERIFICATION". Trajalo bo približno 1-2 delovna dni, da bo transakcija vidna na izpisku.
Ko imate zneske, se vrnite na to stran plačilnega sredstva in kliknite na "Complete Verification".',
    'unknown_bank' => 'Nepoznana banka',
    'ach_verification_delay_help' => 'Račun boste lahko uporabljali šele po končanem preverjanju. Preverjanje običajno traja 1-2 delovnih dni.',
    'add_credit_card' => 'Dodaj kreditno kartico',
    'payment_method_added' => 'Dodano plačilno sredstvo.',
    'use_for_auto_bill' => 'Uporabi za Samodejni Račun',
    'used_for_auto_bill' => 'Samodejno plačilno sredstvo',
    'payment_method_set_as_default' => 'Nastavi samodejno plačilno sredstvo',
    'activity_41' => ':payment_amount plačilo (:payment) ni uspelo',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Morate :link.',
    'stripe_webhook_help_link_text' => 'dodajte ta URL kot končno točko v Stripe',
    'gocardless_webhook_help_link_text' => 'dodaj ta URL kot končno točko v GoCardlessadd',
    'payment_method_error' => 'Pri dodajanju plačilnega sredsgtva je prišlo do napake. Prosim poskusite kasneje.',
    'notification_invoice_payment_failed_subject' => 'Payment :invoice ni bilo uspešno',
    'notification_invoice_payment_failed' => 'Plačilo stranke: :client računa :invoice ni uspelo. Plačilo je bil označeno kot neuspešno in znesek je bil dodan k strankini bilanci.',
    'link_with_plaid' => 'Poveži račun nemudoma z Plaid',
    'link_manually' => 'Poveži ročno',
    'secured_by_plaid' => 'Zavarovan z Plaid',
    'plaid_linked_status' => 'Vaš bančni račun pri :bank',
    'add_payment_method' => 'Dodaj plačilno sredstvo',
    'account_holder_type' => 'Tip nosilca računa',
    'ach_authorization' => 'Pooblaščam :company za uporabo mojega bančnega računa za prihodnja plačila. Razumem, da lahko prekličem pooblastilo kadarkoli z odstranitvijo plačilnega sredstva ali z zahtevo na naslov :email.',
    'ach_authorization_required' => 'Potrebno je soglasje ACH transakcij.',
    'off' => 'Izklopljeno',
    'opt_in' => 'Privzeto izklopljeno',
    'opt_out' => 'Privzeto vklopljeno',
    'always' => 'Vedno',
    'opted_out' => 'Zavrnil',
    'opted_in' => 'Pristopil',
    'manage_auto_bill' => 'Uredi samodejni račun',
    'enabled' => 'Omogočeno',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Omogoči PayPal nakazila čez BrainTree',
    'braintree_paypal_disabled_help' => 'PayPal prehod upravlja Paypal plačila',
    'braintree_paypal_help' => 'Potrebno je tudi :link.',
    'braintree_paypal_help_link_text' => 'povezati PayPay z vašim BrainTree računom ',
    'token_billing_braintree_paypal' => 'Shrani plačilne podatke',
    'add_paypal_account' => 'Dodaj Paypal račun',


    'no_payment_method_specified' => 'Plačilno sredstvo ni izbrano.',
    'chart_type' => 'Tip grafikona',
    'format' => 'Oblika',
    'import_ofx' => 'Uvozi OFX',
    'ofx_file' => 'OFX datoteka',
    'ofx_parse_failed' => 'Razčleniti datoteke OFX ni bila uspešna',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Prijavi se z WePay',
    'use_another_provider' => 'Uporabi drugega ponudnika',
    'company_name' => 'Naziv podjetja',
    'wepay_company_name_help' => 'To se bo pojavilo na strankinih izpiskih kreditne kartice.',
    'wepay_description_help' => 'Namen tega računa',
    'wepay_tos_agree' => 'Strinjam se z :link.',
    'wepay_tos_link_text' => 'WePay pogoji storitve',
    'resend_confirmation_email' => 'Znova pošlji potrditveno e-pošto',
    'manage_account' => 'Nastavitve računa',
    'action_required' => 'Potrebno ukrepanje',
    'finish_setup' => 'Dokončaj nastavitev',
    'created_wepay_confirmation_required' => 'Preverite e-pošto da potrdite vaš e-poštni naslov z WePay.',
    'switch_to_wepay' => 'Preklopite na WePay',
    'switch' => 'Proklop',
    'restore_account_gateway' => 'Obnovi prehod',
    'restored_account_gateway' => 'Prehod uspešno obnovljen',
    'united_states' => 'United States',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Sprejmi debetne kartice',
    'debit_cards' => 'Debetne kartice',

    'warn_start_date_changed' => 'Naslednji račun bo poslan v začetku naslednjega dne,',
    'warn_start_date_changed_not_sent' => 'Naslednji račun bo ustvarjen na nov začetni datum.',
    'original_start_date' => 'Prvotni začetni datum',
    'new_start_date' => 'Novi začetni datum',
    'security' => 'Varnost',
    'see_whats_new' => 'Kaj je novega v: :version',
    'wait_for_upload' => 'Prosim počakajte da se prenos zaključi.',
    'upgrade_for_permissions' => 'Omogoči dovoljenja z nadgradnjo na naš poslovni paket.',
    'enable_second_tax_rate' => 'Omogoči drugi davek',
    'payment_file' => 'Datoteka plačil',
    'expense_file' => 'Datoteka stroškov',
    'product_file' => 'Datoteka izdelkov',
    'import_products' => 'Uvozi izdelke',
    'products_will_create' => 'izdelki bodo ustvarjeni',
    'product_key' => 'Izdelki',
    'created_products' => 'Uspešno ustvarjenih/posodobljenih :count izdelkov',
    'export_help' => 'Uporabite JSON če nameravate uvoziti podatke v Invoice Ninja. <br/> Datoteka vsebuje stranke, izdelke, račune, predračune in plačila.',
    'selfhost_export_help' => '<br/>Za ustvarjanje popolne varnostne kopije priporočamo uporabo mysqldump.',
    'JSON_file' => 'JSON Datoteka',

    'view_dashboard' => 'Prikaži/skrij',
    'client_session_expired' => 'Seja je potekla',
    'client_session_expired_message' => 'Vaša seja je potekla. Prosimo ponovno kliknite na link v vaši e-pošti.',

    'auto_bill_notification' => 'This invoice will automatically be billed to your :payment_method on file on :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'Bančni račun',
    'auto_bill_payment_method_credit_card' => 'kreditna kartica',
    'auto_bill_payment_method_paypal' => 'PayPal račun',
    'auto_bill_notification_placeholder' => 'Ta račun bo samodejno bremenili vašo kreditno kartico v datoteki na dan zapadlosti.',
    'payment_settings' => 'Nastavitev plačil',

    'on_send_date' => 'Na datum plačila',
    'on_due_date' => 'Na datum zapadlosti',
    'auto_bill_ach_date_help' => 'ACH bo vedno izvedel plačilo na dan zapadlosti.',
    'warn_change_auto_bill' => 'Zaradi NACHA pravil, lahko spremembe tega računa preprečijo samodejni ACH račun.',

    'bank_account' => 'Bančni račun',
    'payment_processed_through_wepay' => 'ACH plačila bodo izvedena preko WePay.',
    'wepay_payment_tos_agree' => 'Strinjam se z WePay :terms in :privacy_policy.',
    'privacy_policy' => 'Pravilnik o zasebnosti',
    'wepay_payment_tos_agree_required' => 'Morate se strinjati z WePay pogoji storitve in pravilnikom o zasebnosti.',
    'ach_email_prompt' => 'Prosim, vnesite vaš e-poštni naslov:',
    'verification_pending' => 'Preverjanje v teku',

    'update_font_cache' => 'Prosimo, da osvežite stran za posodobitev predpomnilnika pisave.',
    'more_options' => 'Več možnosti',
    'credit_card' => 'Kreditna kartica',
    'bank_transfer' => 'Bančno nakazilo',
    'no_transaction_reference' => 'Nismo prejeli plačilne transakcijske reference od prehoda.',
    'use_bank_on_file' => 'Uporabi bančno datoteko',
    'auto_bill_email_message' => 'Ta račun bo samodejno zaračunan z uporabo plačilnega sredstva na dan zapadlosti.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Dodano :date',
    'failed_remove_payment_method' => 'Načina plačila ni bilo mogoče odstraniti.',
    'gateway_exists' => 'Prehod že obstaja',
    'manual_entry' => 'Ročni vnos',
    'start_of_week' => 'Prvi dan v tednu',

    // Frequencies
    'freq_inactive' => 'Nedejaven',
    'freq_daily' => 'Dnevno',
    'freq_weekly' => 'Tedensko',
    'freq_biweekly' => 'Dvakrat na teden',
    'freq_two_weeks' => 'Dva tedna',
    'freq_four_weeks' => 'Štiri tedni',
    'freq_monthly' => 'Mesečno',
    'freq_three_months' => 'Trije meseci',
    'freq_four_months' => 'Na štiri mesece',
    'freq_six_months' => 'Šest mesecev',
    'freq_annually' => 'Letno',
    'freq_two_years' => 'Na dve leti',

    // Payment types
    'payment_type_Apply Credit' => 'Potrdi dobropis',
    'payment_type_Bank Transfer' => 'Bančno nakazilo',
    'payment_type_Cash' => 'Gotovina',
    'payment_type_Debit' => 'Bremenitev',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa kartica',
    'payment_type_MasterCard' => 'Master kartica',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover kartica',
    'payment_type_Diners Card' => 'Diners kartica',
    'payment_type_EuroCard' => 'Euro kartica',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Ostale kreditne kartice',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google denarnica',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Računovodstvo in Pravosodje',
    'industry_Advertising' => 'Oglaševanje',
    'industry_Aerospace' => 'Letalska industrija',
    'industry_Agriculture' => 'Kmetijstvo',
    'industry_Automotive' => 'Avtomobilizem',
    'industry_Banking & Finance' => 'Bančništvo in finance',
    'industry_Biotechnology' => 'Biotehnologija',
    'industry_Broadcasting' => 'Radiotelevizija',
    'industry_Business Services' => 'Poslovne storitve',
    'industry_Commodities & Chemicals' => 'Surovine in kemikalije',
    'industry_Communications' => 'Komunikacije',
    'industry_Computers & Hightech' => 'Računalništvo',
    'industry_Defense' => 'Obramba',
    'industry_Energy' => 'Energija',
    'industry_Entertainment' => 'Zabava',
    'industry_Government' => 'Vlada',
    'industry_Healthcare & Life Sciences' => 'Zdravstvo',
    'industry_Insurance' => 'Zavarovalništvo',
    'industry_Manufacturing' => 'Proizvodnja',
    'industry_Marketing' => 'Oglaševanje',
    'industry_Media' => 'Mediji',
    'industry_Nonprofit & Higher Ed' => 'Neprofitne organizacije',
    'industry_Pharmaceuticals' => 'Farmacevtski izdelki',
    'industry_Professional Services & Consulting' => 'Svetovanje',
    'industry_Real Estate' => 'Nepremičnina',
    'industry_Restaurant & Catering' => 'Restavracije in Catering',
    'industry_Retail & Wholesale' => 'Trgovina na drobno in debelo',
    'industry_Sports' => 'Šport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Potovalne agencije',
    'industry_Other' => 'Ostalo',
    'industry_Photography' => 'Fotografija',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarktika',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andora',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Avstralija',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrajn',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgium',
    'country_Bermuda' => 'Bermudi',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia and Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Zelenortski otoki',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Kostarika',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denmark',
    'country_Dominica' => 'Dominika',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Faroe Islands',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fidži',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'France',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Džibuti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germany',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Greece',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Gvatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Gvajana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungary',
    'country_Iceland' => 'Iceland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Izrael',
    'country_Italy' => 'Italy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamajka',
    'country_Japan' => 'Japonska',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuvajt',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuania',
    'country_Luxembourg' => 'Luksemburg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldivi',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinik',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritus',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monako',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Poland',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Portoriko',
    'country_Qatar' => 'Katar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russian Federation',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Angvila',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapur',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenija',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spain',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turkey',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Otok Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'United States',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Bražilščina - Portugalska',
    'lang_Croatian' => 'Hrvaščina',
    'lang_Czech' => 'Češčina',
    'lang_Danish' => 'Danščina',
    'lang_Dutch' => 'Nizozemščina',
    'lang_English' => 'Angleščina',
    'lang_French' => 'Francoščina',
    'lang_French - Canada' => 'Francoščina - Kanada',
    'lang_German' => 'Nemščina',
    'lang_Italian' => 'Italijanščina',
    'lang_Japanese' => 'Japonščina',
    'lang_Lithuanian' => 'Litovščina',
    'lang_Norwegian' => 'Norveščina',
    'lang_Polish' => 'Poljščina',
    'lang_Spanish' => 'Španščina',
    'lang_Spanish - Spain' => 'Španščina - Španija',
    'lang_Swedish' => 'Švedščina',
    'lang_Albanian' => 'Albanščina',
    'lang_Greek' => 'Grško',
    'lang_English - United Kingdom' => 'Angleščina - Združeno Kraljestvo',
    'lang_English - Australia' => 'Angleško - Australia',
    'lang_Slovenian' => 'Slovenščina',
    'lang_Finnish' => 'Finščina',
    'lang_Romanian' => 'Romunščina',
    'lang_Turkish - Turkey' => 'Turščina - Turčija',
    'lang_Portuguese - Brazilian' => 'Portugalščina - Brazilija',
    'lang_Portuguese - Portugal' => 'Portugalščina - Portugalska',
    'lang_Thai' => 'Tajščina',
    'lang_Macedonian' => 'Makedonsko',
    'lang_Chinese - Taiwan' => 'Kitajsko - Taiwan',
    'lang_Serbian' => 'Srbsko',
    'lang_Bulgarian' => 'Bolgarsko',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Računovodstvo in Pravosodje',
    'industry_Advertising' => 'Oglaševanje',
    'industry_Aerospace' => 'Letalska industrija',
    'industry_Agriculture' => 'Kmetijstvo',
    'industry_Automotive' => 'Avtomobilizem',
    'industry_Banking & Finance' => 'Bančništvo in finance',
    'industry_Biotechnology' => 'Biotehnologija',
    'industry_Broadcasting' => 'Radiotelevizija',
    'industry_Business Services' => 'Poslovne storitve',
    'industry_Commodities & Chemicals' => 'Surovine in kemikalije',
    'industry_Communications' => 'Komunikacije',
    'industry_Computers & Hightech' => 'Računalništvo',
    'industry_Defense' => 'Obramba',
    'industry_Energy' => 'Energija',
    'industry_Entertainment' => 'Zabava',
    'industry_Government' => 'Vlada',
    'industry_Healthcare & Life Sciences' => 'Zdravstvo',
    'industry_Insurance' => 'Zavarovalništvo',
    'industry_Manufacturing' => 'Proizvodnja',
    'industry_Marketing' => 'Oglaševanje',
    'industry_Media' => 'Mediji',
    'industry_Nonprofit & Higher Ed' => 'Neprofitne organizacije',
    'industry_Pharmaceuticals' => 'Farmacevtski izdelki',
    'industry_Professional Services & Consulting' => 'Svetovanje',
    'industry_Real Estate' => 'Nepremičnina',
    'industry_Retail & Wholesale' => 'Trgovina na drobno in debelo',
    'industry_Sports' => 'Šport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Potovalne agencije',
    'industry_Other' => 'Ostalo',
    'industry_Photography' => 'Fotografija',

    'view_client_portal' => 'Poglej portal za stranke',
    'view_portal' => 'Poglej portal',
    'vendor_contacts' => 'Kontakt prodajalca',
    'all' => 'Vse',
    'selected' => 'Izbrano',
    'category' => 'Kategorija',
    'categories' => 'Katergorije',
    'new_expense_category' => 'Nova katergorija stroškov',
    'edit_category' => 'Uredi kategorijo',
    'archive_expense_category' => 'Arhiviraj kategorijo',
    'expense_categories' => 'Kategorije stroškov',
    'list_expense_categories' => 'Seznam kategorije stroškov',
    'updated_expense_category' => 'Kategorija stroškov uspešno nadgrajena',
    'created_expense_category' => 'Kategorija stroškov uspešno ustvarjena',
    'archived_expense_category' => 'Kategorija stroškov uspešno arhivirana',
    'archived_expense_categories' => 'Kategorija stroškov :count uspešno arhivirana',
    'restore_expense_category' => 'Obnovi katergorija stroškov',
    'restored_expense_category' => 'Kategorija stroškov uspešno obnovljena',
    'apply_taxes' => 'Potrdi davke',
    'min_to_max_users' => 'od :min do :max uporabnikov',
    'max_users_reached' => 'Doseženo je bilo največje število uporabnikov.',
    'buy_now_buttons' => 'Gumbi za takojšnji nakup',
    'landing_page' => 'Začetna stran',
    'payment_type' => 'Način plačila',
    'form' => 'Obrazec',
    'link' => 'Povezava',
    'fields' => 'Polja',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Opomba: stranka in račun bosta ustvarjena tudi, če je transakcija ni zaključena.',
    'buy_now_buttons_disabled' => 'Ta funkcija zahteva, da je izdelek ustvarjen in plačilni prehod nastavljen.',
    'enable_buy_now_buttons_help' => 'Omogoči podporo za "Kupi Zdaj" gumbe',
    'changes_take_effect_immediately' => 'Opomba: spremembe bodo začele veljati takoj',
    'wepay_account_description' => 'Plačilni prehod za Invoice Ninja',
    'payment_error_code' => 'Pri izvedbi plačila je prišlo do napake [:code]. Prosim poizkusite ponovno.',
    'standard_fees_apply' => 'Provizija: 2.9%/1.2% [Kreditna Kartica/Bančno Nakazilo] + $0.30 za uspešen prenos.',
    'limit_import_rows' => 'Podatke je treba uvoziti v serijah po :count vrstic ali manj',
    'error_title' => 'Nekaj ​​je šlo narobe',
    'error_contact_text' => 'Če želite pomoč nam je pišite na :mailaddress',
    'no_undo' => 'Opozorilo: Tega ni mogoče razveljaviti.',
    'no_contact_selected' => 'Prosim izberite kontakt',
    'no_client_selected' => 'Prosim izberite stranko',

    'gateway_config_error' => 'To lahko pomaga določiti novo geslo ali ustvariti nove API ključe.',
    'payment_type_on_file' => ':type na datoteko',
    'invoice_for_client' => 'Račun :invoice za :client',
    'intent_not_found' => 'Oprostite, nisem prepričan kaj sprašujete.',
    'intent_not_supported' => 'Žal mi je, tega ni mogoče narediti.',
    'client_not_found' => 'Nisem mogel najti stranke',
    'not_allowed' => 'Žal nimate potrebnih dovoljenj',
    'bot_emailed_invoice' => 'Vaš račun je bil poslan.',
    'bot_emailed_notify_viewed' => 'Ob ogledu pošljemo e-poštno sporočilo.',
    'bot_emailed_notify_paid' => 'Ob plačilu pošljemo e-poštno sporočilo.',
    'add_product_to_invoice' => 'Dodaj 1 :product',
    'not_authorized' => 'Nimate dovoljenja',
    'bot_get_email' => 'Živjo! (wave)<br/>Hvala za preizkus Invoice Ninja Bot-a.<br/>Za uporabo je potreben brezplačen račun.<br/>Za nadaljevanje mi pošlji svoj naslov elektronske pošte.',
    'bot_get_code' => 'Hvala! Poslali smo vam e-poštno sporočilo z varnostno kodo.',
    'bot_welcome' => 'To je to!  Vaš račun je preverjen.<br/>',
    'email_not_found' => 'Za :email ni bilo mogoče najti razpoložljivega računa',
    'invalid_code' => 'Koda ni pravilna',
    'security_code_email_subject' => 'Varnostna koda za Invoice Ninja Robot',
    'security_code_email_line1' => 'Ta je vaša varnostna koda za Invoice Ninja Robot',
    'security_code_email_line2' => 'Opomba: poteče v 10 minutah.',
    'bot_help_message' => 'Trenutno podpiram:<br/>• Ustvari\posodobi\pošlji račun<br/>• Seznam izdelkov<br/>N primer:<br/><i>Izstavi račun za 2 karti, nastavi zapadlost na naslednji četrtek in 10 odstotkov popusta</i>',
    'list_products' => 'Seznam izdelkov',

    'include_item_taxes_inline' => 'Prikaži <b>davke v vrstici skupno</b>',
    'created_quotes' => 'Uspešno ustvarjenih :count predračun(ov)',
    'limited_gateways' => 'Opomba: podpiramo en prehod s kreditno kartico na podjetje.',

    'warning' => 'Opozorilo',
    'self-update' => 'Nadgradnja',
    'update_invoiceninja_title' => 'Posodobi Invoice Ninja',
    'update_invoiceninja_warning' => 'Preden začnete nadgradnjo ustvarite varnostno kopijo baze podatkov in datotek!',
    'update_invoiceninja_available' => 'Nova različica Invoice Ninje je na voljo.',
    'update_invoiceninja_unavailable' => 'Nove različice Invoice Ninje ni na voljo.',
    'update_invoiceninja_instructions' => 'Prosim namestite novo različico <strong>:version</strong> z klikom na  <em>Nadgradi Zdaj</em> gumba spodaj. Nato boste preusmerjeni na nadzorno ploščo.',
    'update_invoiceninja_update_start' => 'Posodobi zdaj',
    'update_invoiceninja_download_start' => 'Prenesi :version',
    'create_new' => 'Ustvari',

    'toggle_navigation' => 'Preklop navigacije',
    'toggle_history' => 'Preklop zgodovine',
    'unassigned' => 'Ne-dodeljen',
    'task' => 'Opravilo',
    'contact_name' => 'Kontaktno ime',
    'city_state_postal' => 'Mesto/Država/Pošta',
    'custom_field' => 'Polje po meri',
    'account_fields' => 'Polja podjetja',
    'facebook_and_twitter' => 'Facebook in Twitter',
    'facebook_and_twitter_help' => 'Pomagajte projetku s spremljanjem virov',
    'reseller_text' => 'Opomba: White-label licenca je namenjena za osebno uporabo. Če želite aplikacijo prodajati, nam prosim pišite na :email',
    'unnamed_client' => 'Neimenovana stranka',

    'day' => 'Dan',
    'week' => 'Teden',
    'month' => 'Mesec',
    'inactive_logout' => 'Bili ste odjavljeni zaradi neaktivnosti',
    'reports' => 'Poročila',
    'total_profit' => 'Skupen dobiček',
    'total_expenses' => 'Skupni stroški',
    'quote_to' => 'Predračun za',

    // Limits
    'limit' => 'Omejitev',
    'min_limit' => 'Minimalno: :min',
    'max_limit' => 'Maksimalno: :max',
    'no_limit' => 'Brez omejitev',
    'set_limits' => 'Nastavi :gateway_type omejitve',
    'enable_min' => 'Omogoči minimalno',
    'enable_max' => 'Omogoči maximalno',
    'min' => 'Minimalno',
    'max' => 'Maksimalno',
    'limits_not_met' => 'Račun ne izpolnjuje zahtevanih omjeitev za ta način plačila.',

    'date_range' => 'Časovno obdobje',
    'raw' => 'HTML',
    'raw_html' => 'Raw HTML',
    'update' => 'Nadgradnja',
    'invoice_fields_help' => 'Povleci in spusti polja za spremembo vrstnega reda in lokacije.',
    'new_category' => 'Nova kategorija',
    'restore_product' => 'Obnovi izdelek',
    'blank' => 'Prazno',
    'invoice_save_error' => 'Pri shranjevanju računa je prišlo do napake.',
    'enable_recurring' => 'Omogoči ponavljanje',
    'disable_recurring' => 'Onemogoči ponavljanje',
    'text' => 'Niz',
    'expense_will_create' => 'strošek bo ustvarjen',
    'expenses_will_create' => 'stroški bodo ustvarjeni',
    'created_expenses' => 'Število uspešno ustvarjenih stroškov:',

    'translate_app' => 'Pomagajte nam izboljšati naše prevode z :link',
    'expense_category' => 'Kategorija stroškov',

    'go_ninja_pro' => 'Izberi Ninja Pro!',
    'go_enterprise' => 'Izberi enterprise!',
    'upgrade_for_features' => 'Nadgradi za več možnosti',
    'pay_annually_discount' => 'Letno plačaj za 10 mesecev + 2 brezplačno!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'VašePodjetje.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Prilagodite vsak vidik svojega računa!',
    'enterprise_upgrade_feature1' => 'Nastavi pravice za posamezne uporabnike',
    'enterprise_upgrade_feature2' => 'Pripni zunanje dokumente k računom in ponudbam',
    'much_more' => 'Še veliko več!',
    'all_pro_fetaures' => 'In vse ostalo v Pro paketu!',

    'currency_symbol' => 'Simbol',
    'currency_code' => 'Valuta',

    'buy_license' => 'Kupi licenco',
    'apply_license' => 'Potrdi licenco',
    'submit' => 'Oddaj',
    'white_label_license_key' => 'Licenčni ključ',
    'invalid_white_label_license' => '"White Label" licenca ni veljavna',
    'created_by' => 'Ustvaril :name',
    'modules' => 'Moduli',
    'financial_year_start' => 'Prvi mesec v letu',
    'authentication' => 'Overovitev',
    'checkbox' => 'Potdritveno polje',
    'invoice_signature' => 'Podpis',
    'show_accept_invoice_terms' => 'Potrditev pogojev računa',
    'show_accept_invoice_terms_help' => 'Stranka mora potrditi strinjanje s pogoji na računu.',
    'show_accept_quote_terms' => 'Potrditev pogojev predračuna',
    'show_accept_quote_terms_help' => 'Stranka mora potrditi strinjanje s pogoji na predračunu.',
    'require_invoice_signature' => 'Podpis računa',
    'require_invoice_signature_help' => 'Zahteva od stranke, da zagotovi svoj podpis.',
    'require_quote_signature' => 'Podpis predračuna',
    'require_quote_signature_help' => 'Zahteva od stranke, da zagotovi svoj podpis.',
    'i_agree' => 'Strinjam se s pogoji.',
    'sign_here' => 'Prosimo, da se podpišete tukaj:',
    'authorization' => 'Overovitev',
    'signed' => 'Podpisan',

    // BlueVine
    'bluevine_promo' => 'Pridobi prilagodljiva poslovna področja kreditiranja in odkup računov z uporabo BlueVine.',
    'bluevine_modal_label' => 'Prijavi se z BlueVine',
    'bluevine_modal_text' => '<h3>Hitro financiranje za vaše podjetje. Brez papirologije</h3>
<ul><li>Prožna poslovna področja kreditiranja in odkup računov.</li></ul>',
    'bluevine_create_account' => 'Ustvari račun',
    'quote_types' => 'Pridobi predračun za',
    'invoice_factoring' => 'Odkup računov',
    'line_of_credit' => 'Kreditna linija',
    'fico_score' => 'Vaša FICO ocena',
    'business_inception' => 'Datum ustanovitve podjetja',
    'average_bank_balance' => 'Povprečni saldo bančnega računa',
    'annual_revenue' => 'Letni prihodki',
    'desired_credit_limit_factoring' => 'Željena omejitev odkupa računa',
    'desired_credit_limit_loc' => 'Željena omejitev kreditne linije',
    'desired_credit_limit' => 'Željena omejitev kredita',
    'bluevine_credit_line_type_required' => 'Izbrati morate vsaj eno',
    'bluevine_field_required' => 'To polje je obvezno',
    'bluevine_unexpected_error' => 'Zgodila se je nepričakovana napaka.',
    'bluevine_no_conditional_offer' => 'Preden pošljemo predračun potrebujemo več informacij. Kliknite spodaj za nadaljevanje.',
    'bluevine_invoice_factoring' => 'Odkup računov',
    'bluevine_conditional_offer' => 'Pogojno ponudba',
    'bluevine_credit_line_amount' => 'Kreditna linija',
    'bluevine_advance_rate' => 'Izboljšana stopnja',
    'bluevine_weekly_discount_rate' => 'Tedenska stopnja popusta',
    'bluevine_minimum_fee_rate' => 'Minimalna provizija',
    'bluevine_line_of_credit' => 'Kreditna linija',
    'bluevine_interest_rate' => 'Obrestna mera',
    'bluevine_weekly_draw_rate' => 'Tedenska mera',
    'bluevine_continue' => 'Nadaljuj v BlueVine',
    'bluevine_completed' => 'BlueVine prijava končana',

    'vendor_name' => 'Prodajalec',
    'entity_state' => 'Stanje',
    'client_created_at' => 'Datum vnosa',
    'postmark_error' => 'Pri pošiljanju e-pošte prek Postmark: :link je prišlo do težave.',
    'project' => 'Projekt',
    'projects' => 'Projekti',
    'new_project' => 'Now projekt',
    'edit_project' => 'Uredi projekt',
    'archive_project' => 'Arhiviraj projekt',
    'list_projects' => 'Seznam projektov',
    'updated_project' => 'Projekt uspešno posodobljen',
    'created_project' => 'Projekt uspešno ustvarjen',
    'archived_project' => 'Projekt uspešno arhiviran',
    'archived_projects' => 'Število uspešno arhiviranih projektov: :count',
    'restore_project' => 'Obnovi projekt',
    'restored_project' => 'Projekt uspešno obnovljen',
    'delete_project' => 'Izbriši projekt',
    'deleted_project' => 'Projekt uspešno odstranjen',
    'deleted_projects' => 'Število uspešno odstranjenih projektov: :count',
    'delete_expense_category' => 'Odstrani kategorijo',
    'deleted_expense_category' => 'Kategorija uspešno odstranjena',
    'delete_product' => 'Izbriši izdelek',
    'deleted_product' => 'Izdelek uspešno odstranjen',
    'deleted_products' => 'Število uspešno odstranjenih izdelkov: :count',
    'restored_product' => 'Izdelek uspešno obnovljen',
    'update_credit' => 'Posodobi dobropis',
    'updated_credit' => 'Uspešno posodobljen dobropis',
    'edit_credit' => 'Uredi dobropis',
    'realtime_preview' => 'Predogled v realnem času',
    'realtime_preview_help' => 'Pred urejanjem računa osvežite predogled PDF na strani računa.<br/>To onemogočite, da izboljšate učinkovitost pri urejanju računov.',
    'live_preview_help' => 'Pokaži predogled PDF računa v živo',
    'force_pdfjs_help' => 'Zamenjajte vgrajen PDF pregledovalnik v brskalniku :chrome_link in :firefox_link.<br/>Omogočite to, če je vaš brskalnik PDF datoteke prenaša samodejno. ',
    'force_pdfjs' => 'Prepreči prenos',
    'redirect_url' => 'Preusmeritveni URL',
    'redirect_url_help' => 'Poljubno dodajte naslov za preusmeritev po vnešenem plačilu.',
    'save_draft' => 'Shrani osnutek',
    'refunded_credit_payment' => 'Vrnitev dobropis plačila',
    'keyboard_shortcuts' => 'Bližnjice na tipkovnici',
    'toggle_menu' => 'Preklop menija',
    'new_...' => 'Novo ...',
    'list_...' => 'Seznam ...',
    'created_at' => 'Ustvarjen dne',
    'contact_us' => 'Kontakt',
    'user_guide' => 'Navodila',
    'promo_message' => 'Nadgradi pred potekom :expires in pridobi :amount popusta za prvo leto našega Pro ali Podjetniškega paketa.',
    'discount_message' => ':amount popusta zapade :expires',
    'mark_paid' => 'Označi kot plačano',
    'marked_sent_invoice' => 'Račun označen kot poslan',
    'marked_sent_invoices' => 'Računi označeni kot poslani',
    'invoice_name' => 'Račun',
    'product_will_create' => 'izdelek bo ustvarjen',
    'contact_us_response' => 'Hvala za vaše sporočilo! Poskušali se bomo odzvati čim prej.',
    'last_7_days' => 'Zadnjih 7 dni',
    'last_30_days' => 'Zadnjih 30 dni',
    'this_month' => 'Ta mesec',
    'last_month' => 'Zadnji mesec',
    'current_quarter' => 'To četrtletje',
    'last_quarter' => 'Prejšnje četrtletje',
    'last_year' => 'Zadnje leto',
    'custom_range' => 'Obseg po meri',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Zahtevaj',
    'license_expiring' => 'Opozorilo: Vaša licenca zapade čez: :count days. Za ogled klikni :link ',
    'security_confirmation' => 'Vaš e-poštni naslov je potrjen.',
    'white_label_expired' => 'Vaša while label licenca je potekla. Prosimo razmislite o podaljšanju za pomoč in podporo našemu projektu.',
    'renew_license' => 'Obnovi licenco',
    'iphone_app_message' => 'Na voljo je tudi :link',
    'iphone_app' => 'iPhone aplikacija',
    'android_app' => 'Andorid aplikacija',
    'logged_in' => 'Prijavljeni',
    'switch_to_primary' => 'Za nadzor članstva preklopi na primarno podjetje (:name).',
    'inclusive' => 'Vključeno',
    'exclusive' => 'Ekskluzivno',
    'postal_city_state' => 'Pošta/Mesto/Država',
    'phantomjs_help' => 'Za generiranje PDF datotek v določenih primerih aplikacija uporablja  :link_phantom.  Namesti :link_docs za lokalno generiranje.',
    'phantomjs_local' => 'Uporabi lokalni PhantomJS',
    'client_number' => 'Št. stranke',
    'client_number_help' => 'Določi predpono ali uprabi lasten vzorec za določitev številk strank.',
    'next_client_number' => 'Naslednja št. stranke je :number.',
    'generated_numbers' => 'Ustvarjene številke',
    'notes_reminder1' => 'Prvi popmnik',
    'notes_reminder2' => 'Drugi opomnik',
    'notes_reminder3' => 'Tretji opomnik',
    'notes_reminder4' => 'Opomnik',
    'bcc_email' => 'BCC',
    'tax_quote' => 'Davek predračuna',
    'tax_invoice' => 'Davek računa',
    'emailed_invoices' => 'Račun uspešno poslan',
    'emailed_quotes' => 'Uspešno poslani predračuni',
    'website_url' => 'URL naslov strani',
    'domain' => 'Domena',
    'domain_help' => 'Uporabljeno v portalu za stranke in pri pošiljanju e-pošte.',
    'domain_help_website' => 'Uporabljeno pri pošiljanju e-poštnih sporočil.',
    'import_invoices' => 'Uvozi račune',
    'new_report' => 'Novo poročilo',
    'edit_report' => 'Uredi poročilo',
    'columns' => 'Stolpci',
    'filters' => 'Filtri',
    'sort_by' => 'Razvrsti po',
    'draft' => 'Osnutek',
    'unpaid' => 'Neplačano',
    'aging' => 'Staranje',
    'age' => 'Starost',
    'days' => 'Dnevi',
    'age_group_0' => '0 - 30 Dni',
    'age_group_30' => '30 - 60 Dni',
    'age_group_60' => '60 - 90 Dni',
    'age_group_90' => '90 - 120 Dni',
    'age_group_120' => '120+ dni',
    'invoice_details' => 'Detalji računa',
    'qty' => 'Količina',
    'profit_and_loss' => 'Profit in izguba',
    'revenue' => 'Prihodki',
    'profit' => 'Profit',
    'group_when_sorted' => 'Razvrščanje po skupinah',
    'group_dates_by' => 'Združi datume v',
    'year' => 'Leto',
    'view_statement' => 'Ogled izpiska',
    'statement' => 'Izpisek',
    'statement_date' => 'Datum izpiska',
    'mark_active' => 'Označi kot Aktivno',
    'send_automatically' => 'Pošlji samodeljno',
    'initial_email' => 'Prva e-pošta',
    'invoice_not_emailed' => 'Ta račun ni bil poslan.',
    'quote_not_emailed' => 'Ta predračun ni bil poslan.',
    'sent_by' => 'Poslano od uporabnika :user',
    'recipients' => 'Prejemniki',
    'save_as_default' => 'Shrani kot privzeto',
    'start_of_week_help' => 'Uporaba pri izbiri datuma',
    'financial_year_start_help' => 'Uporaba pri izbiri časovnega odbodja',
    'reports_help' => 'Shift + Klik za razvrščanje po več stolpcih, Ctrl + Klik počisti razvrščanje.',
    'this_year' => 'To leto',

    // Updated login screen
    'ninja_tagline' => 'Ustvari. Pošlji. Prejmi Plačilo.',
    'login_or_existing' => 'Ali pa se prijavite s povezanim računom',
    'sign_up_now' => 'Prijavi se',
    'not_a_member_yet' => 'Še nisi član?',
    'login_create_an_account' => 'Ustvari račun!',

    // New Client Portal styling
    'invoice_from' => 'Računi za:',
    'email_alias_message' => 'Vsako podjetje potrebuje unikaten e-poštni naslov. <br/>Razmislite o uporabi vzdevka, kot na primer:  naslov+oznaka@primer.si',
    'full_name' => 'Polno ime',
    'month_year' => 'MESEC/LETO',
    'valid_thru' => 'Veljaven',

    'product_fields' => 'Polja izdelka',
    'custom_product_fields_help' => 'Pri ustvarjanju izdelka ali računa dodaj polje in na PDF dokumentu prikaži oznako in vrednost.',
    'freq_two_months' => 'Dva meseca',
    'freq_yearly' => 'Letno',
    'profile' => 'Profil',
    'payment_type_help' => 'Privzeto bo izbran ta <b>način ročnega plačila</b>.',
    'industry_Construction' => 'Gradnja',
    'your_statement' => 'Vaša izjava',
    'statement_issued_to' => 'Izjava izdana za',
    'statement_to' => 'Izjava za',
    'customize_options' => 'Prilagodite možnosti',
    'created_payment_term' => 'Plačilni pogoji uspešno ustvarjeni',
    'updated_payment_term' => 'Plačilni pogoji uspešno posodobljeni',
    'archived_payment_term' => 'Plačilni pogoji uspešno arhivirani',
    'resend_invite' => 'Znova pošlji vabilo',
    'credit_created_by' => 'Dobropis ustvarjen na podlagi plačila :transaction_reference',
    'created_payment_and_credit' => 'Plačilo in dobropis uspešno ustvarjena',
    'created_payment_and_credit_emailed_client' => 'Uspešno ustvarjeno plačilo in dobropis in poslano stranki',
    'create_project' => 'Ustvari projekt',
    'create_vendor' => 'Ustvari prodajalca',
    'create_expense_category' => 'Ustvari kategorijo',
    'pro_plan_reports' => ':link za omogočiti poročila s prijavo na naš Pro paket',
    'mark_ready' => 'Označi kot pripravljeno',

    'limits' => 'Omejitve',
    'fees' => 'Provizije',
    'fee' => 'Provizija',
    'set_limits_fees' => 'Nastavi omejitve in provizije za prehod :gateway_type',
    'fees_tax_help' => 'Omogoči davke postavk za nastavitev provizij davčnih stopenj.',
    'fees_sample' => 'Provizija od zneska :amount računa bo :total.',
    'discount_sample' => 'Popust od zneska :amount računa bo :total.',
    'no_fees' => 'Brez provizij',
    'gateway_fees_disclaimer' => 'Opozorilo: Vse države/plačilni prehodi ne dovolijo dodajanje provizij. Preverite lokalno zakonodajo in pogoje uporabe.',
    'percent' => 'Odstotek',
    'location' => 'Lokacija',
    'line_item' => 'Vrstična postavka',
    'surcharge' => 'Doplačilo',
    'location_first_surcharge' => 'Omogočeno - Prvo doplačilo',
    'location_second_surcharge' => 'Omogočeno - Drugo doplačilo',
    'location_line_item' => 'Omogočeno - Vrstična postavka',
    'online_payment_surcharge' => 'Doplačilo pri spletnem plačilu',
    'gateway_fees' => 'Provizije prehodov',
    'fees_disabled' => 'Provizije so onemogočene',
    'gateway_fees_help' => 'Pri spletnem plačilu samodejno dodaj doplačilo/popust.',
    'gateway' => 'Prehod',
    'gateway_fee_change_warning' => 'V primeru neplačanih računov z provizijami, jih je treba posodobiti ročno.',
    'fees_surcharge_help' => 'Prilagodi doplačilo :link.',
    'label_and_taxes' => 'Oznake in davki',
    'billable' => 'Plačljivo',
    'logo_warning_too_large' => 'Slikovna datoteka je prevelika.',
    'logo_warning_fileinfo' => 'Opozorilo: Za gif podporo potrebujete fileinfo PHP dodatek omogočen.',
    'logo_warning_invalid' => 'Pri branju slikovne datoteke je prišlo do težave, poskusite z drugačno obliko datoteke.',

    'error_refresh_page' => 'Prišlo je do napake, prosimo osvežite stran in poskusite znova.',
    'data' => 'Podatki',
    'imported_settings' => 'Nastavitve uspešno uvožene',
    'reset_counter' => 'Ponastavi števec',
    'next_reset' => 'Naslednja ponastavitev',
    'reset_counter_help' => 'Samodejno ponastavi števec predračunov in računov.',
    'auto_bill_failed' => 'Samodejno fakturiranje za račun :invoice_number ni bilo uspešno',
    'online_payment_discount' => 'Pupoust na spletno plačilo',
    'created_new_company' => 'Novo podjetje uspešno ustvarjeno',
    'fees_disabled_for_gateway' => 'Za ta prehod so provizije onemogočene.',
    'logout_and_delete' => 'Odjava/Odstani račun',
    'tax_rate_type_help' => 'Vključujoče davčne stopnje prilagodijo stroške postavke, če so izbrane.<br/>Samo izvzete davčne stopnje se lahko uporabijo kot privzete.',
    'invoice_footer_help' => 'Za prikaz informacij strani uporabi $pageNumber in $pageCount.',
    'credit_note' => 'Dobropis',
    'credit_issued_to' => 'Dobropis izdan za',
    'credit_to' => 'Dobropis za',
    'your_credit' => 'Vaš dobropis',
    'credit_number' => 'Št. dobropisa',
    'create_credit_note' => 'Ustvari dobropis',
    'menu' => 'Meni',
    'error_incorrect_gateway_ids' => 'Napaka: Tabela prehoda ima napačne IDs.',
    'purge_data' => 'Izprazni podatke',
    'delete_data' => 'Izbriši podatke',
    'purge_data_help' => 'Trajno izbriši vse podatke, ohrani pa nastavitve in uporabniški račun.',
    'cancel_account_help' => 'Trajno izbri vse podatke v računu, skupaj z računom in nastavitvami.',
    'purge_successful' => 'Podatki podjetja uspešno odstranjeni',
    'forbidden' => 'Prepovedano',
    'purge_data_message' => 'Opozorilo: Vaši podatki bodo trajno zbrisani. Razveljavitev kasneje ni mogoča.',
    'contact_phone' => 'Kontaktni telefon',
    'contact_email' => 'Kontaktna e-pošta',
    'reply_to_email' => 'Reply-To',
    'reply_to_email_help' => 'Določi naslov, na katerega se lahko odgovori na poslano pošto.',
    'bcc_email_help' => 'Pri pošiljanju e-pošte stranki, pošlji zasebno kopijo na ta naslov.',
    'import_complete' => 'Vaš vnos je uspešno izveden.',
    'confirm_account_to_import' => 'Potrdite svoj račun za uvoz podatkov.',
    'import_started' => 'Vaš uvoz se je začel. Ko se konča vam bomo poslali e-pošto.',
    'listening' => 'Poslušanje ...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Glasovni ukazi',
    'sample_commands' => 'Vzorčni ukazi',
    'voice_commands_feedback' => 'Aktivno si prizadevamo izboljšati storitev. Če imate ukaz, ki bi želeli da ga vključimo, nam prosim pišite na :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Poštna Nakaznica',
    'archived_products' => 'Število uspešno arhiviranih izdelkov: :count',
    'recommend_on' => 'Priporočamo da <b>omogočite</b> to nastavitev.',
    'recommend_off' => 'Priporočamo da <b>onemogočite</b> to nastavitev.',
    'notes_auto_billed' => 'Samodejno zaračunan',
    'surcharge_label' => 'Oznaka doplačila',
    'contact_fields' => 'Polja kontakta',
    'custom_contact_fields_help' => 'Pri ustvarjanju stika dodajte polje in po želji prikažite oznako in vrednost v dokumentu PDF.',
    'datatable_info' => 'Prikazano :start do :end od :total vpisov',
    'credit_total' => 'Dobropis skupaj',
    'mark_billable' => 'Označi plačljivo',
    'billed' => 'Zaračunano',
    'company_variables' => 'Spremenljivke podjetja',
    'client_variables' => 'Spremenljivke stranke',
    'invoice_variables' => 'Spremenljivke računa',
    'navigation_variables' => 'Spremenljivke navigacije',
    'custom_variables' => 'Lastne spremenljivke',
    'invalid_file' => 'Napačen tip datoteke',
    'add_documents_to_invoice' => 'Pripni datoteke',
    'mark_expense_paid' => 'Označi plačano',
    'white_label_license_error' => 'Ni uspelo potrditi licence, preveri storage/logs/laravel-error.log za več podrobnosti.',
    'plan_price' => 'Cene paketa',
    'wrong_confirmation' => 'Nepravilna potrditvena koda',
    'oauth_taken' => 'Račun je že registriran',
    'emailed_payment' => 'Plačilo poslano po elektronski pošti',
    'email_payment' => 'Pošlji plačilo po elektronki pošti',
    'invoiceplane_import' => 'Uporabi :link za migracijo podatkov iz InvoicePlane.',
    'duplicate_expense_warning' => 'Pozor: Tole je lahko podvojeno: :link',
    'expense_link' => 'strošek',
    'resume_task' => 'Nadaljuj opravilo',
    'resumed_task' => 'Opravilo uspešno ponovno zagnano',
    'quote_design' => 'Predloga predračuna',
    'default_design' => 'Osnovna predloga',
    'custom_design1' => 'Po meri 1',
    'custom_design2' => 'Po meri 2',
    'custom_design3' => 'Po meri 3',
    'empty' => 'Prazno',
    'load_design' => 'Noloži obliko',
    'accepted_card_logos' => 'Prikazani logotipi katric',
    'phantomjs_local_and_cloud' => 'Uporabljam lokalni PhantomJS, z alternativo phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Sledi plačilom z :link',
    'start_date_required' => 'Začetni datum je obvezen',
    'application_settings' => 'Nastavitve aplikacije',
    'database_connection' => 'Povezava do podatkovne baze',
    'driver' => 'Gonilnik',
    'host' => 'Gostitelj',
    'database' => 'Podatkovna baza',
    'test_connection' => 'Test povezave',
    'from_name' => 'Od (ime)',
    'from_address' => 'Od (naslov)',
    'port' => 'Vrata',
    'encryption' => 'Enkripcija',
    'mailgun_domain' => 'Mailgun domena',
    'mailgun_private_key' => 'Mailgun zasebni ključ',
    'send_test_email' => 'Pošlji testno sporočilo',
    'select_label' => 'Izberi oznako',
    'label' => 'Oznaka',
    'service' => 'Storitev',
    'update_payment_details' => 'Posodobi podrobnosti plačila',
    'updated_payment_details' => 'Podrobnosti plačila uspešno posodobljeni',
    'update_credit_card' => 'Posodobi kreditno kartico',
    'recurring_expenses' => 'Ponavaljajoči stroški',
    'recurring_expense' => 'Ponavaljajoči stroški',
    'new_recurring_expense' => 'Nov ponavaljajoč strošek',
    'edit_recurring_expense' => 'Uredi ponavaljajoč strošek',
    'archive_recurring_expense' => 'Arhiviraj ponavaljajoč strošek',
    'list_recurring_expense' => 'Seznam ponavaljajočih stroškov',
    'updated_recurring_expense' => 'Ponavaljajoč strošek uspešno posodobljen',
    'created_recurring_expense' => 'Ponavaljajoč strošek uspešno ustvarjen',
    'archived_recurring_expense' => 'Ponavaljajoč strošek uspešno arhiviran',
    'restore_recurring_expense' => 'Obnovi ponavljajoč strošek',
    'restored_recurring_expense' => 'Ponavaljajoč strošek uspešno obnovljen',
    'delete_recurring_expense' => 'Izbriši ponavljajoč strošek',
    'deleted_recurring_expense' => 'Project uspešno odstranjen',
    'view_recurring_expense' => 'Poglej ponavljajoč strošek',
    'taxes_and_fees' => 'Davki in pristojbine',
    'import_failed' => 'Uvoz ni uspel',
    'recurring_prefix' => 'Predpona ponavljajočih',
    'options' => 'Možnosti',
    'credit_number_help' => 'Nastavite predpono ali uporabite vzorec za dinamično nastavljanje številke za negativne račune.',
    'next_credit_number' => 'Naslednja številka dobropisa je :number.',
    'padding_help' => 'Število ničel, ki se doda na začetek števila.',
    'import_warning_invalid_date' => 'Pozor: Oblika datuma izgleda napačno.',
    'product_notes' => 'Zaznamki izdelka',
    'app_version' => 'Verzija aplikacije',
    'ofx_version' => 'Verzija OFX',
    'gateway_help_23' => ':link do Stripe API ključev.',
    'error_app_key_set_to_default' => 'Napaka: APP_KEY je nastavljen na privzeto vrednost, preden ga posodobite ustvarite varnostno kopijo podatkovne baze in nato zaženite <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Fakturiraj zamudne obresti',
    'late_fee_amount' => 'Vrednost zamudnih obresti',
    'late_fee_percent' => 'Odstotek za zamudne obresti',
    'late_fee_added' => 'Zamudne obresti dodane :date',
    'download_invoice' => 'Prenesi račun',
    'download_quote' => 'Prenesi predračun',
    'invoices_are_attached' => 'Računi v PDF obliki so pripeti.',
    'downloaded_invoice' => 'Poslana bo e-pošta s predračunom v obliki PDF',
    'downloaded_quote' => 'Poslana bo e-pošta s predračunom v obliki PDF',
    'downloaded_invoices' => 'Poslana bo e-pošta s predračuni v obliki PDF',
    'downloaded_quotes' => 'Poslana bo e-pošta s predračunom v obliki PDF',
    'clone_expense' => 'Kloniraj strošek',
    'default_documents' => 'Privzeti dokumenti',
    'send_email_to_client' => 'Pošlji e-pošto stranki',
    'refund_subject' => 'Vračilo obdelano',
    'refund_body' => 'Vračilo v znesku :amount za račun :invoice_number je bilo obdelano.',

    'currency_us_dollar' => 'Ameriški dolar',
    'currency_british_pound' => 'Britanski funt',
    'currency_euro' => 'Evro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danska Krona',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Švedska Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norveška Krona',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Hrvaška Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Češka Krona',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Srbski Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Konvertibilne Marke',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'Upamo da uživate v uporabi aplikacije.<br/>Zelo bi cenili klik na :link!',
    'writing_a_review' => 'pisanje pregleda (kritike)',

    'use_english_version' => 'Prepričajte se, da uporabljate angleško verzijo datotek.<br/>Za ujemanje polj uporabljamo naslove stolpcev.',
    'tax1' => 'Prvi davek',
    'tax2' => 'Drugi davek',
    'fee_help' => 'Stroški prehoda so tisti, ki vam jih zaračuna finančna ustanova, ki obdeluje online plačila.',
    'format_export' => 'Format izvoza',
    'custom1' => 'Prvi po meri',
    'custom2' => 'Drugi po meri',
    'contact_first_name' => 'Ime kontakta',
    'contact_last_name' => 'Priimek konakta',
    'contact_custom1' => 'Prvi po meri za kontakt',
    'contact_custom2' => 'Drugi po meri za kontakt',
    'currency' => 'Valuta',
    'ofx_help' => 'Za odpravljanje težav preverite komentarje na :ofxhome_link in testirajte z :ofxget_link.',
    'comments' => 'komentarji',

    'item_product' => 'Predmeti izdelka',
    'item_notes' => 'Zaznamki predmeta',
    'item_cost' => 'Cena predmeta',
    'item_quantity' => 'Količina predmeta',
    'item_tax_rate' => 'Davčna stopnja predmeta',
    'item_tax_name' => 'Ime davčne stopnje predmeta',
    'item_tax1' => 'Predmetni davek1',
    'item_tax2' => 'Predmetni davek2',

    'delete_company' => 'Izbriši podjetje',
    'delete_company_help' => 'Trajno izbriši podjetje, skupaj z vsemi podatki in nastavitvami.',
    'delete_company_message' => 'Opozorilo: Vaše podjetne bo trajno zbrisano. Razveljavitev ni mogoča.',

    'applied_discount' => 'Kupon je bil sprejet, cena je znižana za :discount%.',
    'applied_free_year' => 'Kupon je bil sprejet, vaš račun je za obdobje enega leta brezplačno nadgrajen v pro paket.',

    'contact_us_help' => 'Če poročate o napaki, prosimo dodajte dnevniške datoteke iz storage/logs/laravel-error.log',
    'include_errors' => 'Vsebuje napake',
    'include_errors_help' => 'Vsebuje :link iz storage/logs/laravel-error.log',
    'recent_errors' => 'nedavne napake',
    'customer' => 'Stranka',
    'customers' => 'Stranke',
    'created_customer' => 'Stranka uspešno ustvarjena',
    'created_customers' => 'Število uspešno ustvarjenih strank: :count',

    'purge_details' => 'Podatki o vašem podjetju (:company) so bili uspešno počiščeni.',
    'deleted_company' => 'Podjetje uspešno odstranjeno',
    'deleted_account' => 'Račun uspešno preklican',
    'deleted_company_details' => 'Vaš račun za podjetje (:account) je bil uspešno odstranjen.',
    'deleted_account_details' => 'Vaš račun (:account) je bil uspešno odstranjen.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA direktna bremenitev',
    'enable_alipay' => 'Omogoči Alipay',
    'enable_sofort' => 'Omogoči EU bančne prenose',
    'stripe_alipay_help' => 'Prehode je potrebno še aktivirati v :link.',
    'calendar' => 'Koledar',
    'pro_plan_calendar' => ':link za uporabo koledarja s prijavo v Pro Plan',

    'what_are_you_working_on' => 'Na čem delate?',
    'time_tracker' => 'Časovni sledilnik',
    'refresh' => 'Osveži',
    'filter_sort' => 'Filtriraj/sortiraj',
    'no_description' => 'Ni opisa',
    'time_tracker_login' => 'Prijava v časovni sledilnik',
    'save_or_discard' => 'Shranite ali zavrzite spremembe',
    'discard_changes' => 'Zavrzi spremembe',
    'tasks_not_enabled' => 'Opravila niso omogočena.',
    'started_task' => 'Opravilo uspešno pričeto',
    'create_client' => 'Ustvari stranko',

    'download_desktop_app' => 'Prenesi namizno aplikacijo',
    'download_iphone_app' => 'Prenesi iPhone aplikacijo',
    'download_android_app' => 'Prenesi Android aplikacijo',
    'time_tracker_mobile_help' => 'Dvakrat se dotaknite opravila da ga izberete',
    'stopped' => 'Ustavljeno',
    'ascending' => 'Naraščajoče',
    'descending' => 'Padajoče',
    'sort_field' => 'Uredi po',
    'sort_direction' => 'Smer',
    'discard' => 'Zavrzi',
    'time_am' => 'dop.',
    'time_pm' => 'pop.',
    'time_mins' => 'min',
    'time_hr' => 'ura',
    'time_hrs' => 'ur',
    'clear' => 'Počisti',
    'warn_payment_gateway' => 'Opozorilo: sprejemanje spletnih plačil zahteva da dodate prehod, :link da ga dodate. ',
    'task_rate' => 'Urna postavka',
    'task_rate_help' => 'Privzeto bo to urna postavka za fakturirana opravila.',
    'past_due' => 'Zapadlo',
    'document' => 'Dokument',
    'invoice_or_expense' => 'Račun/strošek',
    'invoice_pdfs' => 'Računi v PDF',
    'enable_sepa' => 'Omogoči SEPA',
    'enable_bitcoin' => 'Omogoči Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'S posredovanjem svoje IBAN številke in potrditvijo tega plačila pooblaščate: podjetje in Stripe, našega ponudnika plačilnih storitev, da na vašo banko pošljete navodila za bremenitev vašega računa, banko pa za bremenitev računa v skladu s temi navodili. Upravičeni ste do povračila sredstev pod pogoji, določenimi v sporazumu z vašo banko. Povračilo je treba zahtevati v 8 tednih od datuma, ko je bil vaš račun bremenjen.',
    'recover_license' => 'Obnovi licenco',
    'purchase' => 'Kupi',
    'recover' => 'Obnovi',
    'apply' => 'Potrdi',
    'recover_white_label_header' => 'Obnovi white label licenco',
    'apply_white_label_header' => 'Omogoči white label licenco',
    'videos' => 'Videji',
    'video' => 'Video',
    'return_to_invoice' => 'Nazaj na račun',
    'gateway_help_13' => 'Za uporabo ITN pustite polje PDT Ključ prazno.',
    'partial_due_date' => 'Delno plačilo do datuma',
    'task_fields' => 'Polja opravila',
    'product_fields_help' => 'Povleci in spusti polja za spremembo vrstnega reda.',
    'custom_value1' => 'Vrednost po meri',
    'custom_value2' => 'Vrednost po meri',
    'enable_two_factor' => 'Dvostopenjska avtentikacija',
    'enable_two_factor_help' => 'Za potrditev vaše identitete pri prijavi uporabite telefon',
    'two_factor_setup' => 'Nastavitev dvostopenjske avtentikacije',
    'two_factor_setup_help' => 'Skenirajte barkodo s aplikacijo kot na primer :link. Spodaj vnesite prvo generirano geslo za enkratno rabo.',
    'one_time_password' => 'Geslo za enkratno uporabo',
    'set_phone_for_two_factor' => 'Preden omogočite funkcijo, za varnost, vnesite številko mobilnega telefona.',
    'enabled_two_factor' => 'Dvostopenjska avtentikacija je omogočena',
    'add_product' => 'Dodaj izdelek',
    'email_will_be_sent_on' => 'Opomba: e-pošta bo poslana :date.',
    'invoice_product' => 'Fakturiraj izdelek',
    'self_host_login' => 'Self-Host prijava',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Napaka: Lokalna hramba ni na voljo.',
    'your_password_reset_link' => 'Povezava za ponastavitev gesla',
    'subdomain_taken' => 'Poddomena že v uporabi',
    'client_login' => 'Vpis stranke',
    'converted_amount' => 'Pretvorjeni znesek',
    'default' => 'Privzeto',
    'shipping_address' => 'Naslov za dostavo',
    'bllling_address' => 'Naslov za račun',
    'billing_address1' => 'Ulica (za račun)',
    'billing_address2' => 'Hišna št./Stanovanje (za račun)',
    'billing_city' => 'Mesto (za račun)',
    'billing_state' => 'Regija/pokrajina (za račun)',
    'billing_postal_code' => 'Poštna št. (za račun)',
    'billing_country' => 'Države (za račun)',
    'shipping_address1' => 'Ulica (za dostavo)',
    'shipping_address2' => 'Hišna št./stanovanje (za dostavo)',
    'shipping_city' => 'Mesto (za dostavo)',
    'shipping_state' => 'Regija/pokrajina (za dostavo)',
    'shipping_postal_code' => 'Poštna št. (za dostavo)',
    'shipping_country' => 'Država (za dostavo)',
    'classify' => 'Razvrsti',
    'show_shipping_address_help' => 'Stranka mora vnesti naslov za dostavo',
    'ship_to_billing_address' => 'Pošlji na naslov računa',
    'delivery_note' => 'Dobavnica',
    'show_tasks_in_portal' => 'Pokaži opravila v portalu za stranke',
    'cancel_schedule' => 'Prekliči urnik',
    'scheduled_report' => 'Načrtovano poročilo',
    'scheduled_report_help' => 'Pošlji poročilo :report v :format na :email',
    'created_scheduled_report' => 'Poročilo uspešno načrtovano',
    'deleted_scheduled_report' => 'Načrtovano poročilo je uspešno preklicano',
    'scheduled_report_attached' => 'Načrtovano poročilo :type je priloženo.',
    'scheduled_report_error' => 'Načrtovanega poročila ni bilo mogoče ustvariti',
    'invalid_one_time_password' => 'Napačno enkratno geslo',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Omogoči Apple Pay in Pay with Google',
    'requires_subdomain' => 'Za ta način plačila je potreben :link.',
    'subdomain_is_set' => 'poddomena ni nastavljena',
    'verification_file' => 'Datoteka za preverjanje',
    'verification_file_missing' => 'Da omogočite plačila je potrebna verifikacijska datoteka.',
    'apple_pay_domain' => 'Uporabi <code>:domain</code> kot domeno v :link:',
    'apple_pay_not_supported' => 'Uprostite, Apple/Google Pay v vašem brskalniku ni podprt',
    'optional_payment_methods' => 'Izbirna plačilna sredstva',
    'add_subscription' => 'Dodaj naročnino',
    'target_url' => 'Cilj',
    'target_url_help' => 'Ko se zgodi izbrani dogodek bo aplikacija poslala entiteto na ciljni URL.',
    'event' => 'Dogodek',
    'subscription_event_1' => 'Stranka ustvarjena',
    'subscription_event_2' => 'Račun ustvarjen',
    'subscription_event_3' => 'Predračun ustvarjen',
    'subscription_event_4' => 'Plačilo ustvarjeno',
    'subscription_event_5' => 'Prodajalec ustvarjen',
    'subscription_event_6' => 'Predračun posodobljen',
    'subscription_event_7' => 'Predračun izbrisan',
    'subscription_event_8' => 'Račun posodobljen',
    'subscription_event_9' => 'Račun izbrisan',
    'subscription_event_10' => 'Stranka posodobljena',
    'subscription_event_11' => 'Stranka izbrisana',
    'subscription_event_12' => 'Plačilo izbrisano',
    'subscription_event_13' => 'Prodajalec posodobljen',
    'subscription_event_14' => 'Prodajalec izbrisan',
    'subscription_event_15' => 'Strošek ustvarjen',
    'subscription_event_16' => 'Strošek posodobljen',
    'subscription_event_17' => 'Strošek izbrisan',
    'subscription_event_18' => 'Opravilo ustvarjeno',
    'subscription_event_19' => 'Opravilo posodobljeno',
    'subscription_event_20' => 'Opravilo izbrisano',
    'subscription_event_21' => 'Predračun potrjen',
    'subscriptions' => 'Naročnina',
    'updated_subscription' => 'Naročnina uspešno posodobljena',
    'created_subscription' => 'Naročnina uspešno ustvarjena',
    'edit_subscription' => 'Uredi naročnino',
    'archive_subscription' => 'Arhiviraj naročnino',
    'archived_subscription' => 'Naročnina uspešno arhivirana',
    'project_error_multiple_clients' => 'Projekti ne morejo pripadati različnim strankam',
    'invoice_project' => 'Fakturiraj projekt',
    'module_recurring_invoice' => 'Ponavljajoči računi',
    'module_credit' => 'Dobropisi',
    'module_quote' => 'Predračuni in ponudbe',
    'module_task' => 'Opravila in projekti',
    'module_expense' => 'Stroški in prodajalci',
    'module_ticket' => 'Tickets',
    'reminders' => 'Opomniki',
    'send_client_reminders' => 'Pošlji opomnike prek e-pošte',
    'can_view_tasks' => 'Opravila so vidna na portalu',
    'is_not_sent_reminders' => 'Opomniki niso poslani',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Prosim, registrirajte vaš račun',
    'processing_request' => 'Obdelujem zahtevo',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Uredi čase',
    'inclusive_taxes_help' => 'Vključi <b>davek v ceni</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Kopiraj naslov za dostavo',
    'copy_billing' => 'Kopiraj naslov za račun',
    'quote_has_expired' => 'Ta predračun je potekel, prosim kontaktiraje prodajalca.',
    'empty_table_footer' => 'Prikazanih 0 od 0 vpisov',
    'do_not_trust' => 'Ne zapomni si te naprave',
    'trust_for_30_days' => 'Zaupaj za 30 dni',
    'trust_forever' => 'Zaupaj za vedno',
    'kanban' => 'Kanban',
    'backlog' => 'Zaostanek',
    'ready_to_do' => 'Pripravljeno',
    'in_progress' => 'V teku',
    'add_status' => 'Dodaj status',
    'archive_status' => 'Arhiviraj status',
    'new_status' => 'Novo stanje',
    'convert_products' => 'Pretvori izdelke',
    'convert_products_help' => 'Samodejno pretvori cene izdelkov v valuto stranke',
    'improve_client_portal_link' => 'Nastavite pod-domeno za skrajšanje povezave na portal.',
    'budgeted_hours' => 'Predvidene ure',
    'progress' => 'Napredek',
    'view_project' => 'Poglej projekt',
    'summary' => 'Povzetek',
    'endless_reminder' => 'Periodičen opomin',
    'signature_on_invoice_help' => 'Dodajte naslednjo kodo da prikažete podpis stranke na PDF.',
    'signature_on_pdf' => 'Prikaži na PDF',
    'signature_on_pdf_help' => 'Prikaži podpis stranke na PDF računu/predračunu.',
    'expired_white_label' => 'Licenca za white label je potekla.',
    'return_to_login' => 'Return to Login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'Vrednost je večja kot saldo, dobropis bo ustvarjen s preostankom.',
    'custom_fields_tip' => 'Uporabi <code>Label|Option1,Option2</code> za prikaz izbora.',
    'client_information' => 'Podatki stranke',
    'updated_client_details' => 'Uspešno osveženi podatki stranke',
    'auto' => 'Auto',
    'tax_amount' => 'Znesek davka',
    'tax_paid' => 'Tax Paid',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Ponudba',
    'proposals' => 'Ponudbe',
    'list_proposals' => 'Seznam ponudb',
    'new_proposal' => 'Nova ponudba',
    'edit_proposal' => 'Uredi ponudbo',
    'archive_proposal' => 'Arhiviraj ponudbo',
    'delete_proposal' => 'Izbriši ponudbo',
    'created_proposal' => 'Ponudba uspešno ustvarjena',
    'updated_proposal' => 'Ponudba uspešno posodobljena',
    'archived_proposal' => 'Ponudba uspešno arhivirana',
    'deleted_proposal' => 'Ponudba uspešno ',
    'archived_proposals' => 'Uspešno arhiviranih :count ponudb',
    'deleted_proposals' => 'Uspešno arhiviranih :count ponudb',
    'restored_proposal' => 'Ponudba uspešno obnovljena',
    'restore_proposal' => 'Obnovi ponudbo',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Predloga',
    'templates' => 'Templates',
    'proposal_template' => 'Template',
    'proposal_templates' => 'Templates',
    'new_proposal_template' => 'New Template',
    'edit_proposal_template' => 'Edit Template',
    'archive_proposal_template' => 'Archive Template',
    'delete_proposal_template' => 'Delete Template',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Category',
    'proposal_categories' => 'Categories',
    'new_proposal_category' => 'New Category',
    'edit_proposal_category' => 'Edit Category',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'Zahtevana ponudba ni na voljo',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Ponudba',
    'proposal_subject' => 'Nova ponudba :number od :account',
    'proposal_message' => 'Za ogled ponudbe vredne :amount, kliknite spodnjo povezavo.',
    'emailed_proposal' => 'Ponudba uspešno poslana',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Opozorilo: če odstranite sliko, bo odstranjena iz vseh ponudb.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Samodejno arhiviraj predračune po pretvorbi.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Stranka mora odobriti predračun.',
    'allow_approve_expired_quote' => 'Dovoli potrjevanje poteklih predračunov',
    'allow_approve_expired_quote_help' => 'Dovoli, da stranka potrdi potekle predračune.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Tok predračuna',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Kloniraj izdelek',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'View Proposal',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Polje izdelka',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Nepotrjen predračun',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Prosim vnesi ključ izdelka',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Prosim vnesi številko predračuna',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Uredi ponavaljajoč predračun',
    'quote_status' => 'Stanje predračuna',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Predračun označen kot poslan',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Kopiraj v predračun',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Prikaži podrobnosti izdelka',
    'show_product_notes_help' => 'Prikaži <b>opis in ceno</b> v spustnem seznamu izdelka',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
